#!/usr/bin/python

# Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

import requests
import collectd

""" Collectd plugin for Number of GPUs and Present GPUs with Bus number"""

PLUGIN_NAME = "gpudevice"
PLUGIN_INSTANCE_COUNT = "gpudevice_count"
PLUGIN_INSTANCE_EXISTING = "gpudevice_existing"
TYPE_INSTANCE = "gpudevice_count"
IP = "localhost"
API = "https://" + str(IP) + ":273/nvsm/v1/Systems/1/GPUs"
GPU_EXIST = {"06:00.0": 0, "07:00.0": 0, "0A:00.0": 0, "0B:00.0": 0,
            "85:00.0": 0, "86:00.0": 0, "89:00.0": 0, "8A:00.0": 0}


def change(num_gpu):
    for key in list(GPU_EXIST.keys()):
        for i in range(num_gpu):
            if key in DATA["GPU"][i]["Connections"]["PCIeLocation"]:
                GPU_EXIST[key] = 1


def dispatch_stat(type_instance, result, plugin_instance):
    val = collectd.Values()
    val.type = 'gauge'
    val.type_instance =  type_instance
    val.plugin = PLUGIN_NAME
    val.plugin_instance = plugin_instance
    val.values = [result]
    val.dispatch()


def read_func():
    try:
        with open('/etc/nvsm/nvsm-perpetual.jwt', 'r') as jwt_file:
            tokenstring = jwt_file.read()

        r = requests.get(str(API), timeout=5, verify=False, headers={'Authorization': 'Bearer '+tokenstring})
        global DATA
        DATA = r.json()
        num_gpu = DATA["NumberOfGPUs"]
        change(num_gpu)
    except Exception as e:
        collectd.error("Call to NVSM REST API Failed : " + str(e))
    else:
        for key, value in GPU_EXIST.items():
            dispatch_stat("GPU_Present_" +key, value, PLUGIN_INSTANCE_EXISTING)
        dispatch_stat(TYPE_INSTANCE, num_gpu, PLUGIN_INSTANCE_COUNT)


collectd.register_read(read_func)

