#!/usr/bin/python

# # Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
# #
# # NVIDIA CORPORATION and its licensors retain all intellectual property
# # and proprietary rights in and to this software, related documentation
# # and any modifications thereto.  Any use, reproduction, disclosure or
# # distribution of this software and related documentation without an express
# # license agreement from NVIDIA CORPORATION is strictly prohibited.

import collectd
import requests

""" Collectd plugin for Number of DIMM correctable and uncorrectable errors
"""

ip = "localhost"


def read_func():
    try:
        with open('/etc/nvsm/nvsm-perpetual.jwt', 'r') as jwt_file:
            tokenstring = jwt_file.read()

        r = requests.get('https://' + str(ip) + ':273/nvsm/v1/Systems/1/Memory/Errors', timeout=5, verify=False, headers={'Authorization': 'Bearer '+tokenstring})
        data = r.json()
    except Exception as e:
        collectd.error("Call to NVSM REST API Failed : " + str(e))
    else:
        num_corr = int(data["Correctable"]["ErrorCount"])
        val = collectd.Values()
        val.type = 'gauge'
        val.type_instance = "mem_corr"
        val.plugin = 'mem_count'
        val.plugin_instance = "mem_count"
        val.dispatch(values=[num_corr])
        num_uncorr = int(data["Uncorrectable"]["ErrorCount"])
        val2 = collectd.Values()
        val2.type = 'gauge'
        val2.type_instance = "mem_uncorr"
        val2.plugin = 'mem_count'
        val2.plugin_instance = "mem_count"
        val2.dispatch(values=[num_uncorr])


collectd.register_read(read_func)
