#!/usr/bin/python

# Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

import collectd
import requests

""" Collectd plugin for PCIE Correctable and Uncorrectable errors
"""


ip = "localhost"


def read_func():
    try:
        with open('/etc/nvsm/nvsm-perpetual.jwt', 'r') as jwt_file:
            tokenstring = jwt_file.read()

        r = requests.get('https://' + str(ip) + ':273/nvsm/v1/Systems/1/Pcie/Errors', timeout=5, verify=False, headers={'Authorization': 'Bearer '+tokenstring})
        data = r.json()
    except Exception as e:
        collectd.error("Call to NVSM REST API Failed : " + str(e))
    else:
        num_corr = data["Correctable"]['ErrorCount']
        num_uncorr = data["Uncorrectable"]["ErrorCount"]
        val = collectd.Values()
        val.type = 'gauge'
        val.type_instance = "pcie_corr"
        val.plugin = 'pcie_count'
        val.plugin_instance = "pcie"
        val.dispatch(values=[num_corr])
        val2 = collectd.Values()
        val2.type = 'gauge'
        val2.type_instance = "pcie_uncorr"
        val2.plugin = "pcie_count"
        val2.plugin_instance = "pcie"
        val2.dispatch(values=[num_uncorr])


collectd.register_read(read_func)
