# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from __future__ import unicode_literals

import json
import re

from nvsm.backend.context import Target, Property, dict_to_properties

import nvsm.exceptions
import nvsm.log
import nvsm.backend.policy as policy

class PagerDutyTarget(Target):
    def __init__(self, address, context):
        super(PagerDutyTarget, self).__init__(
                address=address, context=context)
        self.__chref = 'nvsm/v1/PagerDuty' 
        self.__properties = None
        self.__targets = None

    def __getitem__(self, key):
        # PagerDuty has no targets at this time
        # (behaves as an empty dictionary)
        raise KeyError

    def __initProperties(self):
        assert self.__properties == None
        pagerduty_info = self._context._queryBackend(self.__chref)
        nvsm.log.debug('pagerduty respone', pagerduty_info)
        self.__properties = list(dict_to_properties(target=self, d=pagerduty_info))

    @property
    def targets(self):
        return [] 

    @property
    def properties(self):
        if self.__properties == None:
            # Initialize properties on first access
            self.__initProperties()
        return self.__properties

    #def set(self, name, value):
    def set(self, nameValuePairs):
        if policy.dump_supported() == False:
            raise nvsm.exceptions.CommandError('pagerduty feature not supported on this platform')

        self.set_array(nameValuePairs)

    def set_array(self,nameValuePairs):
        body_dict = {}
        body_dict['Description'] = "User initiated pager duty operation."
        body_dict['Trigger'] = None
        body_dict['DiagTest'] = None

        for pair in nameValuePairs:
            name = pair[0]
            value = pair[1]
            found = False
            nvsm.log.debug('name{0} - value{1}'.format( name,value))

            for x in [ 'Trigger' , 'Description', 'ServiceKey', 'DiagTest']:
                if name.lower() == x.lower():
                    found = True
                    nvsm.log.debug('pagerduty endpoint:{0}', self.__chref)

                    def to_bool(value):
                        if value.lower() == "true":
                            return True
                        elif value.lower() == "false": 
                            return False
                        else: 
                            nvsm.log.warning('Invalid boolean value: {0}', value)
                            return None 

                    if name.lower() == 'trigger' or name.lower() == 'diagtest':
                        value = to_bool(value)
                        if value is None:
                            return 
                    else:
                        if name.lower() == 'description' and value is None:    
                            value = "User initiated pagerduty operation."

                        if name.lower() == 'servicekey' and value is None:    
                            raise nvsm.exceptions.MissingProperty('Invalid PagerDuty servicekey.')

                    body_dict[x] = value

            if found is False:        
                raise nvsm.exceptions.MissingProperty(
                   'Target property "{0}" does not exist'.format(name))

        response = self._context._queryBackend(self.__chref,
                    method='PUT', body=body_dict)

        if hasattr(response, 'get') and response.get('error'):
            nvsm.log.error(response['error'])
        return
