# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.


from nvsm.backend.context import Target, dict_to_properties

import nvsm.log


class VersionsTarget(Target):
    def __init__(self, address, context):
        super(VersionsTarget, self).__init__(
            address=address, context=context)
        self.__properties = None

    def __initProperties(self):
        assert self.__properties == None
        self.__properties = []
        # Get contents of this alert from the NVSM backend
        response = self._context._queryBackend('/nvsm/v1/Versions')
        if 'nvsm' not in response:
            nvsm.log.warning(
                'Could not find "nvsm" attribute in NVSM backend response')
            return
        properties = ['dgx-release', 'dcs-release', 'nvidia-driver', 'cuda-driver', 'os-release',
                      'kernel', 'nvidia-container-runtime-docker', 'docker-ce', 'nvsm', 'platform',
                      'datacenter-gpu-manager', 'datacenter-gpu-manager-fabricmanager', 'mlnx-ofed']

        def filter_properties(name, value):
            if 'odata' in name.lower():
                return False
            if str(value).lower() == '':
                return self._context.showall
            if name.lower() in properties:
                return True
        self.__properties = list(dict_to_properties(
            target=self, d=response, criteria=filter_properties))

    def __getitem__(self, key):
        raise KeyError

    @property
    def targets(self):
        return []

    @property
    def properties(self):
        if self.__properties == None:
            # Initialize properties upon first access
            self.__initProperties()
        return self.__properties
