# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.



import sys
from contextlib import contextmanager

@contextmanager
def colorize(color, bold=False):
    if not colorize.enable:
        yield
        return
    try:
        unset_code = colorize.unset
    except AttributeError:
        # Code to unset color not known; something is wrong
        yield
        return
    try:
        color_code = getattr(colorize, color)
    except AttributeError:
        # Unknown color string
        yield
        return
    sys.stdout.write(color_code.decode('utf-8'))
    yield
    sys.stdout.write(unset_code.decode('utf-8'))
    sys.stdout.flush()

colorize.enable = False

ansi_colors = (
    'black',
    'red',
    'green',
    'yellow',
    'blue',
    'magenta',
    'cyan',
    'white'
)

def init(hint='auto'):
    if hint.lower() == 'never':
        colorize.enable = False
    elif hint.lower() == 'always':
        colorize.enable = True
    elif hint.lower() == 'auto':
        if not sys.stdout.isatty():
            colorize.enable = False
        else:
            colorize.enable = True
    else:
        # Unknown hint; don't colorize
        colorize.enable = False
    if colorize.enable:
        try:
            import curses
        except:
            # Not all systems have curses
            colorize.enable = False
    if colorize.enable:
        try:
            # Initialize curses to learn about terminal
            curses.setupterm()
        except:
            colorize.enable = False
    if colorize.enable:
        # Gather terminfo needed for colorization
        setaf = curses.tigetstr('setaf')
        sgr0 = curses.tigetstr('sgr0')
        if not all([ setaf, sgr0 ]):
            colorize.enable = False
        else:
            for i in range(len(ansi_colors)):
                color_name = ansi_colors[i]
                color_code = curses.tparm(setaf, i)
                setattr(colorize, color_name, color_code)
            colorize.unset = sgr0
