# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.


import copy
import os
import signal
import subprocess
import sys
import re
import logging
from nvsm.color import colorize
import nvsm.command
import nvsm.interpreter
from nvsm.command.queryNGC import PickAndSelect1
import argparse

class ShowDashboardsCommand(nvsm.command.Command):
    def __init__(self, argv):
        super(ShowDashboardsCommand, self).__init__(argv=argv)

        self.prompt = "Enabling NVSM Dashboards will, \
        \n - Create user prometheus & Install official Prometheus version 2.21 - enable prometheus service and use port 9090 \
        \n - Add & Enable the repository %s to system for stable Grafana OSS packages \
        \n - Install latest official Grafana Package - enable grafana service and use port 3000 \
        \n - Enable nvsm-exporter.service for metric collection and use port 9123. \
        \n \nPlease make sure your firewall whitelists the following ports: 9123, 3000 & 9090. \
        \n \nDo you want to continue" % ("https://packages.grafana.com/oss/deb")

        self.logfile = "Logfile: %s" % "/var/log/nvsm/nvsm_dashboard.log"

    @staticmethod
    def implements(argv):
        """ Determine if the given command is an alias for "show health".

        This method allows the NVSM Command factory pattern to determine if
        the "ShowDashboardsCommand" class implements the given command.

        This method returns True if the first two arguments of argv look like
        "show health" case insensitive. Returns False otherwise.
        """
        aliases = [
            [ 'enable', 'dashboard' ],
            [ 'enable', 'dashboards' ] ]
        return [x.lower() for x in argv[:2]] in aliases

    def printColor(self, text, color):
        with colorize(color):
            print(text)

    def run(self, context, file=sys.stdout):

        rc, ans = PickAndSelect1(["no", "yes"], self.prompt)

        if rc != 0 or ans != "yes":
            return


        from nvsm.backend.dashboard import run_enable_dashboard
        exit_code = run_enable_dashboard()
        if exit_code != 0:
            print("Error Observed: ", exit_code)
            print(self.logfile)
        else:
            self.printColor("Success", "green")
            self.printColor("Grafana Server is running at <node-ip>:3000 with default credentials admin/admin", "blue")
            self.printColor("Prometheus is running at <node-ip>:9090", "blue")
            self.printColor("NVSM-Exporter is running at <node-ip>:9123", "blue")


# Register as a command alias with the NVSM Command factory method.
# This allows NVSM to easily construct Commands of this type.
nvsm.command.Command.register_command_alias(ShowDashboardsCommand)
