# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.




import argparse
import sys

import nvsm.command

class ExitCommand(nvsm.command.Command):
    def __init__(self, argv):
        super(ExitCommand, self).__init__(argv=argv)

        self.__parse_arguments()

    def __parse_arguments(self):
        self.__argparser = argparse.ArgumentParser(
                prog='exit',
                description='''Leave the NVSM shell.''',
                add_help=False)
        self.__argparser.add_argument('-help', '-h', action='store_true', default=False,
                help='show this help message and exit')
        try:
            self.options = self.__argparser.parse_args(self.argv[1:])
        except SystemExit as e:
            # TODO: Somehow raise exception with the error message printed by argparse
            raise nvsm.exceptions.InvalidArguments(
                    'Invalid exit command arguments: {0}'.format(
                        ' '.join(self.argv[1:])))

    def run(self, context, file=sys.stdout):
        if self.options.help:
            self.__argparser.print_help(file=file)
            return
        # Raise SystemExit exception to leave the REPL loop
        sys.exit(0)

    @staticmethod
    def implements(argv):
        """ Determine if the given command is an NVSM "exit" command.

        This method allows the NVSM Command factory pattern to determine if
        the ExitCommand class implements the given command name.

        This method returns True if argv[0] is "exit" or "quit", case
        insensitive.  Returns False otherwise.
        """
        if argv[0].lower() in [ 'exit', 'quit' ]:
            return True
        return False

# Register with the NVSM Command factory method.
# This allows NVSM to easily construct Commands of this type.
nvsm.command.Command.register_command(ExitCommand)
