# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.




import sys

import nvsm.command
import nvsm.exceptions
from nvsm.command.show import ShowCommand


class ShowAlertsCommand(nvsm.command.Command):
    def __init__(self, argv):
        super(ShowAlertsCommand, self).__init__(argv=argv)

        # Construct the "show" commands that implement this command alias
        self.__showCommands = []
        alerts_list = ['/chassis/*/thermal/alerts/*',
                  '/chassis/*/power/alerts/*',
                  '/chassis/alerts/*',
                  '/chassis/*/NetworkAdapters/alerts/*',
                  '/chassis/*/NetworkAdapters/*/NetworkPorts/alerts/*',
                  '/chassis/*/NetworkAdapters/*/NetworkDeviceFunctions/alerts/*',
                  '/systems/*/gpus/alerts/*',
                  '/systems/*/nvswitches/alerts/*',
                  '/systems/*/memory/alerts/*',
                  '/systems/*/processors/alerts/*',
                  '/systems/*/pcie/alerts/*',
                  '/systems/*/alerts/*',
                  '/systems/*/storage/alerts/*']
        try:
            # add managers uri only for the platfroms where
            # /managers target is present and working
            _ = self._context._queryBackend('/managers')
            alerts_list.append('/managers/alerts/*')
        except:
            pass
        for t in alerts_list:
            show_argv = ['show',
                         '-level', 'all',
                         '-display', 'properties',
                         t]
            if '-all' in argv:
                show_argv.append('-all')
            command = ShowCommand(argv=show_argv)
            self.__showCommands.append(command)

    @staticmethod
    def implements(argv):
        """ Determine if the given command is an alias for "show alerts".

        This method allows the NVSM Command factory pattern to determine if
        the "ShowAlertsCommand" class implements the given command.

        This method returns True if argv looks like "show alerts", case
        insensitive, and ignoring plurality. Returns False otherwise.
        """
        aliases = [
            [ 'show', 'alert' ],
            [ 'show', 'alerts' ] ]
        argv = [x for x in argv if x != '-all']
        return [x.lower() for x in argv] in aliases

    def run(self, context, file=sys.stdout):
        for c in self.__showCommands:
            try:
                c.run(context=context, file=file)
            except nvsm.exceptions.MissingTarget:
                pass  # No alerts for this particular subsystem


# Register as a command alias with the NVSM Command factory method.
# This allows NVSM to easily construct Commands of this type.
nvsm.command.Command.register_command_alias(ShowAlertsCommand)
