import sys

import nvsm.command
from nvsm.command.show import ShowCommand

class ShowLedCommand(nvsm.command.Command):
    def __init__(self, argv):
        super(ShowLedCommand, self).__init__(argv=argv)

        # Construct the "show" command that implements this command alias
        self.__show_ledstatus = []
        led_list = ['/systems/*/storage/drives/*',
                    '/chassis/*']

        for t in led_list:
            if t == '/systems/*/storage/drives/*':
                show_argv = ['show',
                         '-display', 'Properties=LedStatus',
                         t]
            else:
                show_argv = ['show',
                         '-display', 'Properties=IndicatorLED',
                         t]
            command = ShowCommand(argv=show_argv)
            self.__show_ledstatus.append(command)
    @staticmethod
    def implements(argv):
        """ Determine if the given command is an alias for "show led".

        This method allows the NVSM Command factory pattern to determine if
        the "ShowLedCommand" class implements the given command.

        This method returns True if argv looks like "show led", case
        insensitive. Returns False otherwise.
        """
        aliases = [
            ['show', 'led'],
            ['show', 'ledstatus']]
        return list([x.lower() for x in argv]) in aliases

    def run(self, context, file=sys.stdout):
        for c in self.__show_ledstatus:
            try:
                c.run(context=context, file=file)
            except nvsm.exceptions.MissingTarget:
                pass  # No alerts for this particular subsystem


# Register as a command alias with the NVSM Command factory method.
# This allows NVSM to easily construct Commands of this type.
nvsm.command.Command.register_command_alias(ShowLedCommand)

