# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.




import sys

import nvsm.command
from nvsm.command.show import ShowCommand

class ShowMemoryCommand(nvsm.command.Command):
    def __init__(self, argv):
        super(ShowMemoryCommand, self).__init__(argv=argv)

        # Construct the "show" command that implements this command alias
        show_argv = [ 'show',
                      '-level', 'all',
                      '-display', 'properties',
                      '/systems/*/memory/*' ]
        self.__showCommand = ShowCommand(argv=show_argv)

    @staticmethod
    def implements(argv):
        """ Determine if the given command is an alias for "show memory".

        This method allows the NVSM Command factory pattern to determine if
        the "ShowMemoryCommand" class implements the given command.

        This method returns True if argv looks like "show memory", case
        insensitive, and ignoring plurality. Returns False otherwise.
        """
        aliases = [
            [ 'show', 'memory' ],
            [ 'show', 'dimms' ],
            [ 'show', 'dimm' ] ]
        return [x.lower() for x in argv] in aliases

    def run(self, context, file=sys.stdout):
        return self.__showCommand.run(context=context, file=file)

# Register as a command alias with the NVSM Command factory method.
# This allows NVSM to easily construct Commands of this type.
nvsm.command.Command.register_command_alias(ShowMemoryCommand)
