# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.




import sys

import nvsm.command
from nvsm.command.show import ShowCommand


class ShowPolicyCommand(nvsm.command.Command):
    def __init__(self, argv):
        super(ShowPolicyCommand, self).__init__(argv=argv)

        # Construct the "show" commands that implement this command alias
        self.__showCommands = []
        policy_list = ['/chassis/*/thermal/policy',
                       '/chassis/policy',
                       '/chassis/*/power/policy',
                       '/chassis/*/NetworkAdapters/policy',
                       '/chassis/*/NetworkAdapters/*/NetworkPorts/policy',
                       '/chassis/*/NetworkAdapters/*/NetworkDeviceFunctions/policy',
                       '/systems/*/gpus/policy',
                       '/systems/*/memory/policy',
                       '/systems/*/NVSwitches/policy',
                       '/systems/*/processors/policy',
                       '/systems/*/storage/policy',
                       '/systems/*/pcie/policy',
                       '/policy']
        try:
            # add managers uri only for the platfroms where
            # /managers target is present and working
            _ = self._context._queryBackend('/managers')
            policy_list.append('/managers/policy')
        except:
            pass
        for t in policy_list:
            show_argv = ['show',
                         '-display', 'properties',
                         t]
            command = ShowCommand(argv=show_argv)
            self.__showCommands.append(command)

    @staticmethod
    def implements(argv):
        """ Determine if the given command is an alias for "show policy".

        This method allows the NVSM Command factory pattern to determine if
        the "ShowPolicyCommand" class implements the given command.

        This method returns True if argv looks like "show policy", case
        insensitive. Returns False otherwise.
        """
        aliases = [
            [ 'show', 'policy' ] ]
        return [x.lower() for x in argv] in aliases

    def run(self, context, file=sys.stdout):
        for c in self.__showCommands:
            try:
                c.run(context=context, file=file)
            except nvsm.exceptions.MissingTarget:
                pass  # No policy for this particular subsystem


# Register as a command alias with the NVSM Command factory method.
# This allows NVSM to easily construct Commands of this type.
nvsm.command.Command.register_command_alias(ShowPolicyCommand)
