# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

def init_history():
    import os
    import pwd
    from .pyrepl import readline
    histfile = os.path.join(os.path.expanduser(pwd.getpwuid(os.geteuid())[5]), '.nvsmcli_hist')
    try:
        readline.read_history_file(histfile)
        readline.set_history_length(1000)
    except IOError:
        pass
    import atexit
    atexit.register(readline.write_history_file, histfile)
    del os, pwd, histfile

def make_completer(context):
    from .pyrepl import readline

    def custom_complete(text, state):
        from nvsm.targetAddress import TargetAddress

        linebuf =  readline.get_line_buffer()
        parts = linebuf.decode('utf-8').split()
        plen = len( parts)
        iscomplete = linebuf.decode('utf-8').endswith(' ')

        targets = []
        names = []
        verbs = ['show', 'cd', 'exit', 'set']
        
        # VERB AUTOCOMPLETION
        if plen == 0 or (plen == 1 and not iscomplete):
            results = [ x + ' ' for x in verbs if x.startswith(text)] + [None]
            return results[state]
        
        # ADDRESS AUTOCOMPLETION
        for part in parts:
            if (('/' in part) or part=='.' or part=='..') and iscomplete:
                results = []
                return results[state]

        if iscomplete:
            parts.append('./')

        address_part = parts[-1]

        if address_part[:2] != './' and address_part[0] != '/' and address_part[:3] != '../':
            address_part = './' + address_part

        name = address_part.split('/')[-1]
        if name != '':
            address_part = address_part[:-len(name)]

        targets.extend(context.getTarget(TargetAddress(
            address_part,
            context=context)).targets)

        for target in targets:
            names.append(target.name + '/')

        results = [ x for x in names if x.startswith(name)] + [None]
        return results[state]
    
    readline.set_completer(custom_complete)
    # readline.set_completer_delims( ';')
