# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.



from .ply import yacc
import sys
from nvsm import parsetree

import nvsm.log

"""This module defines the grammar used to parse NVSM input.

This is the grammar defining the NVSM "language" that users provide as input
to the NVSM shell. This "language" is extremely simple at this time. It is
expected that the NVSM language will be extended as the need arises.

Note that there is more than one grammar parsed by NVSM. The grammar defined
in this module is a simple shell language (vaguely resembling bash). However,
each NVSM command defines its own grammar to parse arguments and identify
erroneous arguments.
"""

# Get token map as defined by the lexicon
from nvsm.lexicon import tokens

def p_program_command(p):
    'program : command'
    # Node representing program with a single command
    p[0] = parsetree.ProgramNode()
    p[0].appendCommand(p[1])

def p_program_concatenate(p):
    'program : program SEMICOLON command'
    p[0] = p[1]
    p[0].appendCommand(p[3])

def p_command_expression(p):
    'command : argument'
    # NOTE: The first argument is also the name of the command
    p[0] = parsetree.CommandNode(p[1])

def p_command_concatenate(p):
    'command : command argument'
    p[0] = p[1]
    p[0].appendArgument(p[2])

def p_argument_string(p):
    'argument : STRING'
    # TODO: Un-escape any escapes used in the STRING token
    p[0] = p[1]

def p_error(p):
    nvsm.log.error('Syntax error in NVSM input')
