# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.



from .ply import lex
import re
import sys

import nvsm.log

"""This module defines the tokens used to parse NVSM input.

The tokens currently defined here are intentionally very simple. Only the
minimal set of tokens needed to represent commands in a shell (strings
separated by spaces) are defined.

As NVSM evolves, it is expected that the number of tokens that NVSM recognizes
will grow. For example, future versions of NVSM might recognize quoted
strings, or reserved words for control flow.
"""


tokens = (
    'STRING',
    'SEMICOLON'
)

t_SEMICOLON = r';'

escape_space_pattern = re.compile(r'\\ ')
def t_STRING(t):
#    r'([\w/.,*=:!\(\)@-]|(\\\ ))+'
    r'([\w/.,$*=:!\(\)@-]|(\\\ ))+'
    t.value = escape_space_pattern.sub(' ', t.value)
    return t

def t_ignore_SPACE(t):
    r'\s+'
    pass

def t_newline(t):
    r'\n+'
    t.lexer.lineno += len(t.value)

def t_error(t):
    nvsm.log.warning('lexer encountered illegal character "{0}"', t.value[0])
    t.lexer.skip(1)
