# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.



import logging
import sys

from nvsm.color import colorize

def debug(msg, *args, **kwargs):
    logger.debug('%s', str(msg).format(*args, **kwargs))

def info(msg, *args, **kwargs):
    logger.info('%s', str(msg).format(*args, **kwargs))

def warning(msg, *args, **kwargs):
    logger.warning('%s', str(msg).format(*args, **kwargs))

def error(msg, *args, **kwargs):
    logger.error('%s', str(msg).format(*args, **kwargs))

def critical(msg, *args, **kwargs):
    logger.critical('%s', str(msg).format(*args, **kwargs))

class ColorLogHandler(logging.Handler):
    __colors = {
        logging.DEBUG: 'blue',
        logging.INFO: 'blue',
        logging.WARNING: 'red',
        logging.ERROR: 'red',
        logging.CRITICAL: 'red'
    }
    def __init__(self, level=logging.WARNING, out=sys.stdout):
        super(ColorLogHandler, self).__init__(level=level)
        self.__out = out
        self.setFormatter(logging.Formatter(
                    fmt='%(levelname)s:%(name)s:%(message)s'))

    def handle(self, record):
        if self.__out is sys.stdout:
            color = ColorLogHandler.__colors.get(record.levelno, 'blue')
            with colorize(color=color):
                print(self.format(record), file=self.__out)
        else:
            # To avoid confusing terminal, never use color outside of stdout
            print(self.format(record), file=self.__out)

def init(level=logging.NOTSET, out=sys.stdout):
    global logger
    logger = logging.getLogger('nvsm')
    logger.setLevel(level)
    handler = ColorLogHandler(level=level, out=out)
    logging.getLogger().addHandler(handler)
