# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.



import sys

import nvsm.command

class Program(object):
    @classmethod
    def from_program_node(cls, node, working_target='/'):
        # Construct Command objects from the CommandNodes in the parse tree
        commands = []
        for cn in node.commands:
            # Construct command using factory method
            c = nvsm.command.Command.from_command_node(
                cn, working_target=working_target)
            commands.append(c)
        # Construct the NVSM Program object with all commands
        program = cls(commands=commands)
        return program

    def __init__(self, commands):
        self.commands = commands

    def run(self, context, file=sys.stdout):
        # Current implementation of NVSM program is simply a list of commands.
        # There is no flow control at this time.
        for c in self.commands:
            c.run(context=context, file=file)
