# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.




import sys
import getpass
import textwrap
from .pyrepl import readline  # MIT-licensed readline clone
from nvsm.color import colorize

def Confirmation(message, question, color='None', tag='PROMPT', formatted=True):
    print()
    if formatted:
        formatted_message = '{tag}: {message}'.format(tag=tag, message=message)
        formatted_message = textwrap.wrap(formatted_message,
                width=70, replace_whitespace=True, subsequent_indent=(' ' * (len(tag) + 2)))
        formatted_message = '\n'.join(formatted_message)
        with colorize(color):
            print(formatted_message)
    else:
        print(message)
    prompt = '\n{question} [y/n] '.format(question=question)
    while True:
        response = readline._wrapper.raw_input(prompt).decode('utf-8').lower()
        # remove history item
        if readline.get_current_history_length() > 0:
            readline.remove_history_item(readline.get_current_history_length()-1)

        if response.lower() in [ 'y', 'yes' ]:
            print()
            return True
        if response.lower() in [ 'n', 'no' ]:
            print()
            return False
        print('Please respond with "y" or "n".')

def Warn(message, question, color='None'):
    return Confirmation(message=message, color=color, question=question, tag='WARNING')

def String(message, prompt, default=None, password=False, valid=lambda x: True, re_enter=False):
    print()
    tag = 'PROMPT'
    formatted_message = '{tag}: {message}'.format(tag=tag, message=message)
    formatted_message = textwrap.wrap(formatted_message,
            width=70, replace_whitespace=True, subsequent_indent=(' ' * (len(tag) + 2)))
    formatted_message = '\n'.join(formatted_message)
    print(formatted_message)
    while True:
        if password:
            response = getpass.getpass('\n{} (CTRL-C to cancel): '.format(prompt))
            if re_enter:
                confirm_response = getpass.getpass('{}: '.format('Please re-enter'))
                if response != confirm_response:
                    print("Passwords do not match")
                    continue
        else:
            response = readline._wrapper.raw_input('\n{} (CTRL-C to cancel): '.format(prompt)).decode('utf-8')
            # remove history item
            if readline.get_current_history_length() > 0:
                readline.remove_history_item(readline.get_current_history_length()-1)
        if default and not response.strip():
            print('Selected default option: {}\n'.format(default))
            return default
        if not valid(response):
            print('Unknown input "{}".\nPlease check input and try again.'.format(response))
            continue
        return response.strip()
