# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

"""
A catalog of static alert data
"""

import json
import os
import logging
from nvsm_dshm.infra import config_settings

DEFAULT_DATA_DIR = '/usr/share/dshm/equipment/alerts/'
_FILES = {'environmental': 'env_alerts.json',
          'system': 'system_alerts.json',
          'storage': 'storage_alerts.json',
          'pcie': 'pcie_alerts.json',
          'network': 'network_alerts.json',
          'dcs_hw_api_key': 'dcs_hw_api_key.json'}

_alerts = None

logger = logging.getLogger(__name__)


def init(*subsystems):
    """
    Copies the static data from the file to in-memory
    """
    global _alerts
    data_dir = config_settings().get('data', 'data-dir')
    if data_dir is None:
        data_dir = DEFAULT_DATA_DIR

    for subsystem in subsystems:
        file_name = data_dir + _FILES[subsystem]

        if not os.path.isfile(file_name):
            logger.error('Unable to find the file{}'.format(file_name))
            return False

        with open(file_name, 'r') as fp:
            if not _alerts:
                _alerts = json.loads(fp.read())
            else:
                _alerts.update(json.loads(fp.read()))

    if _alerts is None:
        logger.error(
            'Copying static alert data from the json file {} failed'.format(
                file_name))
        return False

    return True


def get(alert_id):
    """
    Returns the static data for the give alert id.
    """
    if alert_id in list(_alerts.keys()):
        return _alerts[alert_id]
    else:
        logger.critical(
            'The alert {} is not in the alerts catalog'.format(alert_id))
    return None
