#!/usr/bin/python
# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

import json
import os
import yaml
#import exceptions
from nvsm_dshm.infra.singleton import singleton

try:
    from configparser import SafeConfigParser
    from configparser import ConfigParser
    from configparser import ParsingError, NoOptionError, NoSectionError
except ImportError as e:
    sys.exit(1)

DEFAULT_CONFIG = {
    'nvsm-api': {
        'config-file': '/etc/nvsm/nvsm.config'
    },

    'logging': {
        'config-file': '/usr/share/dshm/logging.json',
        'log-dir': '/tmp/'
    }
}


class config_settings(object,  metaclass=singleton):
    '''
        Singleton class to hold all config
    '''
    def __init__(self, config_file_name=None, default_config=DEFAULT_CONFIG):
        self.configParser = ConfigParser(default_config)
        if config_file_name is not None:
            self.configParser.read(config_file_name)

    def get(self, section="", option=""):
        return self.configParser.get(section, option)

    @classmethod
    def nvsm_api_config_helper(cls, file_name):
        serving_port = None
        binding_address = None
        nvsm_api_config = None
        ca_cert_filename = None
        server_cert_filename = None
        server_key_filename = None
        mqtt_server_address = None

        if file_name is not None and os.path.isfile(file_name):
            with open(file_name, 'r') as fhandle:
                config = fhandle.read()
                if config is not None:
                    valid_json = True
                    try:
                        nvsm_api_config = json.loads(config)
                    except:
                        valid_json = False
                    if not valid_json:
                        nvsm_api_config = yaml.safe_load(config)
                    

        if nvsm_api_config is not None:
            ca_cert_filename = nvsm_api_config.get('ca_cert')
            server_cert_filename = nvsm_api_config.get('https_cert')
            server_key_filename  = nvsm_api_config.get('https_priv_key')
            mqtt_server_address  = nvsm_api_config.get('mqtt_server_address')
            serving_port = nvsm_api_config.get('servingport')
            binding_address = nvsm_api_config.get('bindingaddress')

        return (ca_cert_filename, server_cert_filename,
                server_key_filename, mqtt_server_address,
                binding_address, serving_port, None)

