#!/usr/bin/python
# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.


# standard import

import re
import json
import os
import errno

import logging
import logging.config
from logging.handlers import RotatingFileHandler
from logging import Filter


# Add Custom Log Level
ALERT_LEVEL_NUM = 60
logging.addLevelName(ALERT_LEVEL_NUM, "ALERT")


def alert(self, message, *args, **kws):
    if self.isEnabledFor(ALERT_LEVEL_NUM):
        self._log(ALERT_LEVEL_NUM, message, args, **kws)

logging.Logger.alert = alert


def initialize(log_conf, log_dir, component):
    """
    Initializes logging
    """

    # Read log config file
    config = None
    if os.path.isfile(log_conf):
        with open(log_conf, 'r') as fhandle:
            config = fhandle.read()

    if config is None:
        return False

    # Create logging directory path
    try:
        os.makedirs(log_dir)
    except OSError as e:
        if e.errno == errno.EEXIST and os.path.isdir(log_dir):
            pass
        else:
            return False

    log_cfg = json.loads(config)

    log_file_name = log_dir + component + '.log'
    alert_log_file = log_dir + component + '_alerts.log'

    log_cfg['handlers']['rotating_file_handler']['filename'] = log_file_name
    log_cfg['handlers']['alert_file_handler']['filename'] = alert_log_file

    logging.config.dictConfig(log_cfg)

    return True
