# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

# standard import

import enum
import json
import os

# custom import from relative path
from . import singleton
from .dshm_exceptions import file_not_found
from .dshm_exceptions import invalid_input

# creating enumerations using class


class PA_MODE(enum.Enum):
        DISCOVERY = 1
        FILE = 2
        JSON = 3
        NONE = -1


class PA_CONTEXT(enum.Enum):
        URI = 1
        NONE = -1


class uri_query(dict):

    """
        Extended dict Helper class to search URI path in JSON
    """

    def get(self, path, default=None, seperator='/'):
        keys = path.split(seperator)
        val = None

        for key in keys:
            if not key.strip():
                continue

            if val:
                if isinstance(val, list):
                    if key.isdigit():
                        try:
                            val = val[int(key) - 1]
                        except IndexError:
                            val = None
                    else:
                        val = [v.get(key, default) if v else None for v in val]
                else:
                    val = val.get(key, default)
            else:
                val = dict.get(self, key, default)

            if not val:
                break

        return val


class uri_context(object):

    """
        URI search context. Handles URI related data search
    """
    DEFAULT_PROFILE = {
        'Systems': {
        }
    }

    def __init__(self, profile):
        self.json_dict = None
        if profile is None:
            self.json_dict = uri_context.DEFAULT_PROFILE
        else:
            self.json_dict = json.loads(profile,
                                        object_hook=lambda dict: uri_query(
                                            dict))

    def enumerate(self, path=None):
        return self.json_dict.get(path)


class pa(object, metaclass=singleton.singleton):

    """
        A SingleTon class to extract platform specific information
        that is essential for performing health management activities
        on various DGX systems
    """

    def __init__(self, mode=PA_MODE.JSON, context=PA_CONTEXT.URI, **kwargs):
        self.context = None
        self.profile = None

        if mode is PA_MODE.FILE:
            file_name = kwargs['file_name']
            if os.path.isfile(file_name):
                with open(file_name, 'r') as fhandle:
                    self.profile = fhandle.read()
            else:
                raise file_not_found('file not found')
        elif mode is PA_MODE.JSON:
            if 'obj' in kwargs.keys() and kwargs['obj'] is not None:
                self.profile = kwargs['obj']
            else:
                raise invalid_input('invalid input')

        self.context = uri_context(self.profile)

    def enumerate_obj(self, path=None):
        return self.context.enumerate(path)
