import subprocess
import signal
import os
import psutil
import re
from threading import Timer
import logging

logger = logging.getLogger(__name__)
_TIMER = None


def _stop(log_proc):
    process = psutil.Process(log_proc.pid)
    for proc in process.children(recursive=True):
        proc.kill()
    process.kill()


def dump_supported():
    if subprocess.call("which nvsm-health".split()):
        logger.info("nvsm-health is not installed on this machine. Not collecting logs.")
        return False
    return True

# Setting the timeout for collecting logs to 15 minutes (on an average
# nvsm-dump-health takes about 4 minutes, on RHEL it takes about 12 - 13
# minutes)
#timeout=2400 (Luna), TODO: timeout should be configurable
def collect(timeout=2400):
    log_process = subprocess.Popen(['/usr/sbin/nvsm_dump', '--body', '{}'],
                                   stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE,
                                   shell=False)
    _TIMER = Timer(timeout, _stop, (log_process,))
    _TIMER.setDaemon(True)
    _TIMER.start()

    log_out, log_err = log_process.communicate()

    _TIMER.cancel()

    if log_process.returncode:
        if log_err:
            logger.error(
                "Error occurred while collecting logs {}".format(log_err))
        return None
    else:
        if log_err:
            logger.warning(
                "Warning messages while collecting logs {}".format(log_err))

    if log_out:
        result = re.search(rb"/tmp/.*tar.xz", log_out)
        if result:
            # If file size is zero then return None
            if os.stat(result.group(0)).st_size == 0:
                logger.error("Log file {} size is zero".format(result))
                return None

            logger.debug("Generated log file {}".format(log_out))
            return result.group(0)

    logger.error("Failed to generate the log file")
    return None
