import json
import time
import tarfile
import os
import re
from nvsm_dshm.thea import Endpoint
import logging

logger = logging.getLogger(__name__)

def append_file_to_tar(filepath=None, tarpath=None, destinationtarpath=None):
    logger.debug('Adding metdata file to tar started')
    if not os.path.exists(filepath):
        raise Exception("Invalid file path:{}".format(filepath))
    if not os.path.exists(tarpath):
        raise Exception("Invalid tar path:{}".format(tarpath))
    if not destinationtarpath:
        destinationtarpath=tarpath
    import tarfile, lzma, io
    in_memory_tar = io.BytesIO()
    with lzma.open(tarpath) as f:
        in_memory_tar.write(f.read())
    in_memory_tar.seek(0)
    f=tarfile.open(fileobj=in_memory_tar, mode='r')
    dir_name=None
    for member in f.getmembers():
        if member.isdir()==True:
            dir_name=member.name.split('/')[0]
    in_memory_tar.seek(0)
    filename=filepath.split('/')[-1]
    with tarfile.open(fileobj=in_memory_tar, mode='a') as tar:
        tar.add(filepath, arcname="{}/{}".format(dir_name, filename))
    in_memory_tar.seek(0)
    with lzma.open(destinationtarpath, "wb") as g:
        g.write(in_memory_tar.read())
    logger.debug('Adding metdata file to tar finished')
class MetaDataFile:
    def __init__(self, context):
        # TODO: Discuss with Suresh on extra fields
        notifications = context['notifications']
        filtered_notification = []
        for notification in notifications:
            obj = {}
            if notification['severity'] == 'Critical':
                obj["alert_id"]=notification["alert_id"]
                obj["clear_time"]=notification["clear_time"]
                obj["component_id"]=notification["component_id"]
                obj["description"]=notification["description"]
                obj["event_time"]=notification["event_time"]
                obj["message"]=notification["message"]
                obj["message_details"]=notification["message_details"]
                obj["recommended_action"]=notification["recommended_action"]
                obj["severity"]=notification["severity"]
                obj["system_name"]=notification["system_name"]
                obj["system_serial"]=notification["system_serial"]
                obj["type"]=notification["type"]
                filtered_notification.append(obj)

        self.data = {
            'system_serial': Endpoint().serial(),
            'system_name': Endpoint().hostname(),
            'notifications': filtered_notification
            }

    def get_data(self):
        return self.data
    

class OfflineCallHomeDestination:

    def __init__(self, **kwargs):
        #TODO: remove self.context later
        self.context = kwargs.get('context', None)
        if self.context:
            self.log_location = str(self.context['log_location'].decode('utf-8'))
            self.notification =  self.context['notifications']
            #self.tar_file_name = self.log_location.split('/')[-1]
            self.tar_file_pattern = 'offlinecallhome-nvsm-health'
            temp_metadata_location = '/tmp'
            t = time.localtime()
            current_time = time.strftime("%d-%m-%Y-%H-%M-%S-%Z",  t)
            metadata_file_name = "offlinecallhome_notifications_{}_{}_{}.json".format(current_time, Endpoint().hostname(), Endpoint().serial())
            self.tar_file_name = "{}_{}_{}_{}.tar.xz".format(self.tar_file_pattern, current_time, Endpoint().hostname(), Endpoint().serial())
            self.temp_metadata_file_location = '{}/{}'.format(temp_metadata_location, metadata_file_name)

    def connect(self):
        pass
    
    def dump_metadata_file(self):
        # TODO: Add validation for number of log dumps
        self.metadataObj = MetaDataFile(self.context)
        with open(self.temp_metadata_file_location, "w") as write_file:
            json.dump(self.metadataObj.get_data(), write_file, indent=4)
        
    def transfer_dump(self):
        pass

    def disconnect(self):
        pass

    @staticmethod
    # Factory for getting new destinations
    def get_client(context):
        '''
        Supported destinations for offline Callhome
        '''
        if 'log_destination_location' in context['policy'].keys() and context['policy']['log_destination_location']:
            logger.info('OfflineCallHome client: LocalDump')
            return OfflineCallHomeLocal(context=context)
        else:
            raise Exception("Unsupported Offline CallHome client")


class OfflineCallHomeLocal(OfflineCallHomeDestination):

    def __init__(self, context):
        super(OfflineCallHomeLocal, self).__init__(context=context)
        self.log_destination_location = context['policy']['log_destination_location']
        self.no_of_dumps_allowed = context['policy']['no_of_dumps_allowed']
        # TODO: Later to be populated from config file
        self.DEFAULT_DUMP_LOCATION = "/var/log/nvsm_offline_callhome"

    def transfer_dump(self):
        # verify that destination location has less than allowed number of dumps
        if os.path.exists(self.log_destination_location):
            pattern = re.compile(self.tar_file_pattern)
            files = ["{}/{}".format(self.log_destination_location,f) for f in os.listdir(self.log_destination_location) if pattern.match(f)]
            if len(files) >= self.no_of_dumps_allowed:
                oldest_file=min(files, key=os.path.getctime)
                os.remove(oldest_file)
            self.log_destination_file_name = "{}/{}".format(self.log_destination_location, self.tar_file_name)
            append_file_to_tar(filepath=self.temp_metadata_file_location, tarpath=self.log_location, destinationtarpath=self.log_destination_file_name)
            os.remove(self.temp_metadata_file_location)
        else:
            default_dir_created=False
            if not os.path.exists(self.DEFAULT_DUMP_LOCATION):
                os.makedirs(self.DEFAULT_DUMP_LOCATION)
                default_dir_created=True
            self.log_destination_location = self.DEFAULT_DUMP_LOCATION
            if default_dir_created:
                logger.info("OfflineCallHomeLocal: {} path doesn't exist, dump location changed to {}".format(self.log_destination_location, self.DEFAULT_DUMP_LOCATION))
            self.transfer_dump()
