import time
from datetime import datetime
import logging
from threading import Lock


from nvsm_dshm.notifier.call_home.state_machine import CallHome as CallHomeSM
from nvsm_dshm.notifier.notifier_thread import NotifierTask
from nvsm_dshm.thea import Endpoint

logger = logging.getLogger(__name__)


def mock_notification(comment, email):
    notification = {}

    notification['system_serial'] = Endpoint().serial()
    notification['alert_id'] = 'OnDemandCallHome'
    notification['component_id'] = 'Server'
    notification['event_time'] = datetime.now().astimezone().isoformat()
    notification['severity'] = 'Critical'
    notification['clear_time'] = ''
    notification['description'] = comment  # 'User triggered call home operation'
    notification['message_details'] = notification['description']
    notification['message'] = notification['message_details']
    notification['system_name'] = Endpoint().hostname()
    notification['batch_id'] = notification['system_serial'] + "|" + notification['event_time']

    if email is not None and email.strip():
        notification['email'] = email

    return ([notification])


def timestamp(op):
    if not op:
        return 0

    op_start_time = datetime.strptime(op['StartTime'], "%Y-%m-%dT%H:%M:%SZ")
    epoch_time = datetime(1970, 1, 1, 0, 0, 0)
    return (op_start_time - epoch_time).total_seconds()


class OnDemandCHTask(NotifierTask):
    queue_size = 100
    name = 'OnDemandCHTask'

    def __init__(self, webserver, stage, version):  # , jwt_filename):
        super(OnDemandCHTask, self).__init__()
        self.webserver = webserver
        self.stage = stage
        self.version = version
        # self.jwt_filename = jwt_filename

        self.current_op = None
        self.state_machine = None

        self.lock = Lock()

    def put(self, op):
        if op['State'] != 'Cancelled' and op['State'] != 'Pending':
            logger.debug(
                "On Demand call home operation {} is not supported".format(op['State']))
            return

        if op['State'] == 'Cancelled':
            with self.lock:
                if self.current_op and self.state_machine and self.current_op['StartTime'] == op['StartTime']:
                    self.state_machine.stop()
                    return

        if not self.queue.full():
            self.queue.put(op)
        else:
            logger.debug(
                "{} queue is full, unable to process the notification".format(self.name))

    def run(self):
        while True:
            op = self.queue.get()

            ops = {}
            while True:
                key = op['StartTime']
                if key in list(ops.keys()):
                    if op['State'] == 'Cancelled':
                        logger.debug("Op {} was dropped because it was cancelled before it could be processed.".format(
                            op['StartTime']))
                        ops[key] = None
                else:
                    if op['State'] == 'Pending':
                        ops[key] = op
                self.queue.task_done()

                if not self.queue.empty():
                    op = self.queue.get()
                else:
                    ops_list = [
                        o for key, o in list(ops.items()) if o is not None]
                    op = None
                    if ops_list:
                        op = max(ops_list, key=timestamp)
                    break

            if op:
                with self.lock:
                    self.current_op = op
                    batch = mock_notification(op['Description'], op['Email'])
                    self.state_machine = CallHomeSM(
                        self.webserver,
                        self.stage,
                        self.version,
                        # self.jwt_filename,
                        batch,
                        op,
                        op['DiagTest'])

                self.state_machine.run()

                with self.lock:
                    self.op_timestamp = None
                    self.state_machine = None
