import time
import logging


from nvsm_dshm.notifier.call_home.state_machine import CallHome as CallHomeSM
from nvsm_dshm.notifier.notifier_thread import NotifierTask
from nvsm_dshm.policy import IPolicy
from nvsm_dshm.ds import AlertsDataStore
from nvsm_dshm.ds import AlertsNvsmDB
from nvsm_dshm.policy import IPolicy

logger = logging.getLogger(__name__)


EXECUTION_INTERVAL = 600  # CallHomeTask's batch processing is triggered at most once every 10 minutes.
MIN_BATCH_SLEEP_TIME = 10 #This is to wait for a minimum time,this for batching the alerts.


class CallHomeTask(NotifierTask):
    queue_size = 300
    name = 'CallHomeTask'

    def __init__(self, webserver, stage, version):
                 #jwt_filename  

        super(CallHomeTask, self).__init__()
        self.webserver = webserver
        self.stage = stage
        self.version = version
        #self.jwt_filename = jwt_filename
        self.get_batch_interval()


    def put(self, alert):
        callhome_policy = None
        try:
            if not self.policy_enabled():
                logger.info(
                   "Notification is not processed because Call-Home policy is not enabled")
                return
        except Exception as excep:
            logger.error("Failed in getting Call-Home policy, {}".format(str(excep)))


        if alert['severity'] == 'Warning':
            logger.info(
                "Notification is not processed because it is a Warning")
            return

        super(CallHomeTask, self).put(alert)
     
    @classmethod 
    def push_existing_alerts(cls, webserver, stage, version):
        device_types = AlertsNvsmDB.get_supported_devices()
        batch_start_up = []
        batch_id_start_up = None
        batch_unique_alerts = {}

        for device_type in device_types:
            logger.debug("push_existing_alerts: Device Types-Type: {}".format(device_type))
            # Fetch the alerts in the data store
            data_store = AlertsDataStore.factory('thea_db', device_type)
            ret = data_store.fetch_all_active_alerts()
            if ret['errored']:
                logger.error(
                    "Unable to fetch alert data from {} for thea".format(
                        device_type))
                logger.error(
                    'Thea is in-accessible, waiting till connection \
                        is re-established')
                continue

            alerts = ret['alerts']

            for alert in alerts:
                if alert['severity'] == 'Warning':
                    logger.info(
                       "Push existing alerts,Notification is not processed because it is a Warning")
                    continue

                case_id_val_not_present = False
                if 'case_id' in alert:
                    case_value = None
                    case_value = alert['case_id']
                    case_id_val_not_present = case_value is not None and not(case_value and case_value.strip())


                if batch_id_start_up is None and \
                   (not 'case_id' in alert or case_id_val_not_present):
                    batch_id_start_up = alert['system_serial']+"|"+alert['event_time']

                key_id = alert['alert_id'] + '|'+  alert['component_id']
                if (not 'case_id' in alert or case_id_val_not_present) and \
                                     key_id not in batch_unique_alerts:
                    logger.debug("push_existing_alerts: Selected Active Critical Alerts: {}".format(alert))
                    batch_unique_alerts[key_id] = True
                    batch_start_up.insert(0, alert)

        for batch_item in batch_start_up:
            if batch_id_start_up is None:
                batch_id_start_up = batch_item['system_serial']+"|"+batch_item['event_time']
            batch_item['batch_id'] = batch_id_start_up
        
        if batch_start_up:
            logger.debug("push_existing_alerts: Total Selected Active Alerts:{}".format(batch_start_up))
            CallHomeSM(
                       webserver,
                       stage,
                       version,
                       #self.jwt_filename,
                       batch_start_up).run()
    def policy_enabled(self):
        callhome_policy = IPolicy.factory('CallHome')
        if callhome_policy and callhome_policy.get()['enable']:
            return True
        else:
            offlinecallhome_policy = IPolicy.factory('OfflineCallHome')
            if offlinecallhome_policy and offlinecallhome_policy.get()['enable']:
                return True
            else:
                return False

    def get_batch_interval(self):
        if self.policy_enabled():
            offlinecallhome_policy = IPolicy.factory('OfflineCallHome')
            if offlinecallhome_policy is not None and  offlinecallhome_policy.get()['enable']:
                self.execution_interval = offlinecallhome_policy.get()['batch_interval']
            else:
                callhome_policy = IPolicy.factory('CallHome')
                if callhome_policy is not None:
                    self.execution_interval = callhome_policy.get()['batch_interval']

    def policy_enabled(self):
        callhome_policy = IPolicy.factory('CallHome')
        if callhome_policy and callhome_policy.get()['enable']:
            return True
        else:
            offlinecallhome_policy = IPolicy.factory('OfflineCallHome')
            if offlinecallhome_policy and offlinecallhome_policy.get()['enable']:
                return True
            else:
                return False

    def get_batch_interval(self):
        if self.policy_enabled():
            offlinecallhome_policy = IPolicy.factory('OfflineCallHome')
            if offlinecallhome_policy is not None and  offlinecallhome_policy.get()['enable']:
                self.execution_interval = offlinecallhome_policy.get()['batch_interval']
            else:
                callhome_policy = IPolicy.factory('CallHome')
                if callhome_policy is not None:
                    self.execution_interval = callhome_policy.get()['batch_interval']
                

    def run(self):
        timestamp = None
        first_boot = True
        seconds_elapsed = 0

        while True:

            item = self.queue.get()

            if timestamp:
                seconds_elapsed = time.time() - timestamp
                if seconds_elapsed < self.execution_interval:
                    time.sleep(self.execution_interval - seconds_elapsed)
                else:
                    time.sleep(MIN_BATCH_SLEEP_TIME)


            if self.policy_enabled:
                self.get_batch_interval()
                logger.info(
                   "Alert batch interval set to {} seconds.".format(self.execution_interval))

            # Batch all the alerts in the queue
            # NOTE: The notifications in the queue preserve the chronology, but
            # while constructin the batch the chronology will be lost since the
            # alerts data structure used below is a dictionary and it does not
            # preserve order.
            alerts = {}
            while True:
                key = item['component_id'] + '|' + item['alert_id'] + '|' + item['event_time']

                if key in list(alerts.keys()):
                    if item['severity'] == 'Cleared':
                        logger.debug("Alert notification for {}, {}, {} was dropped because it was cleared before the notification was sent.".format(
                            item['component_id'], item['alert_id'], item['event_time']))
                        alerts[key] = None
                    else:
                        alerts[key] = item
                else:
                    alerts[key] = item

                self.queue.task_done()

                if timestamp is None and first_boot:
                    timestamp = time.time()
                    first_boot = False
                    seconds_elapsed = time.time() - timestamp

                    logger.info(
                       "Alert batch interval difference {} seconds.".format(self.execution_interval - seconds_elapsed))

                    if seconds_elapsed < self.execution_interval:
                        time.sleep(self.execution_interval - seconds_elapsed)

                if not self.queue.empty():
                    item = self.queue.get()
                else:
                    batch = []
                    batch_id = None
                    for key, alert in list(alerts.items()):
                        if not alert:
                            continue

                        #Always create the batch-id from an active alert, this ensures a new case.
                        if batch_id is None and alert['severity'] != 'Cleared':
                            batch_id = alert['system_serial']+"|"+alert['event_time']

                        if alert['severity'] == 'Cleared':  # Cleared alerts at the back of the list
                            batch.append(alert)
                        else:  # New alerts at the front of the list
                            batch.insert(0, alert)
                    if batch:
                        for batch_item in batch:
                            if batch_id is None:
                                batch_id = batch_item['system_serial']+"|"+batch_item['event_time']
                            batch_item['batch_id'] = batch_id
                    if batch:
                        timestamp = time.time()
                        CallHomeSM(
                            self.webserver,
                            self.stage,
                            self.version,
                            #self.jwt_filename,
                            batch).run()
                    break

