import smtplib
import logging
import socket

from email.mime.multipart import MIMEMultipart
import smtplib,email,email.encoders,email.mime.text,email.mime.base
from email.mime.text import MIMEText

#from email.MIMEText import MIMEText


from nvsm_dshm.notifier.state_machine import StateMachine, State, state, retry
from nvsm_dshm.policy import IPolicy
from nvsm_dshm.thea import Endpoint

logger = logging.getLogger(__name__)


class Email(StateMachine):
    name = 'Email'
    states = {}
    start_state = ''

    def __init__(self, batch):
        super(Email, self).__init__()
        self.e_context['notifications'] = batch

    def terminate(self):
        super(Email, self).terminate()
        self.e_context['notifications'] = None
        self.e_context['policy'] = None


@Email.add(start_state=True)
@state(on_success='send', on_failure='terminate')
@retry()
def get_config(e_context):
    email_policy = IPolicy.factory('EmailConfig')

    if email_policy.get()['recipients'] and \
       email_policy.get()['smtp-server-name'] and \
       email_policy.get()['smtp-server-port']:
        e_context['policy'] = email_policy.get()
        return True
    else:
        return False


@Email.add
@state(on_success='terminate', on_failure='terminate')
@retry(retries=8, exponential=True)
def send(e_context):

    e_policy = e_context['policy']
    for idx, event in enumerate(e_context['notifications']):

        if not event:
            continue

        ret = send_mail(email_text(event),
                        e_policy['sender'],
                        e_policy['smtp-server-name'],
                        e_policy['smtp-server-port'],
                        e_policy['recipients'])

        if ret:
            e_context['notifications'][idx] = None
        else:
            return False

    return True


def send_mail(message, frm_addr, server_name, server_port, recipients):
    msg = MIMEMultipart()
    msg['From'] = frm_addr
    msg['Subject'] = "NVSM Alert [{}]".format(socket.gethostname())
    msg['To'] = ", ".join(recipients)
    msg.attach(MIMEText(message, 'plain'))

    try:
        server = smtplib.SMTP(server_name, server_port, None, 30)
        server.sendmail(frm_addr, recipients, msg.as_string())
        server.quit()
    except Exception:
        logger.exception("Sending email failed")
        return False

    return True


def email_text(alert):
    """
    Convert to email text message.
    """
    str_format = ("{}: {}\n"
                  "{}: {}\n"
                  "{}: {}\n"
                  "{}: {}\n"
                  "{}: {}\n"
                  "{}: {}\n"
                  "{}: {}\n"
                  "{}: {}\n"
                  "{}: {}\n"
                  "{}: {}\n")

    auto_msg = "This is an automatically generated message from DGX " \
               "System Health Manager running on {} ({})\n\n".format(
                   socket.gethostname(), get_ip_addr())

    # FIXME +id: when we rework primary key for the alerts db, clean this up
    if '+' in alert['component_id']:
        alert['component_id'] = alert['component_id'].split('+')[-1]

    mail_text = str_format.format(
        'Alert Id', alert['alert_id'],
        'Description', alert['description'],
        'Event Time', alert['event_time'],
        'System Name', alert['system_name'],
        'System Serial', alert['system_serial'],
        'Device Id', alert['component_id'],
        'Severity', alert['severity'],
        'Message', alert['message'],
        'Message Details', alert['message_details'],
        'Recommended Action', alert['recommended_action'])

    mail_text = auto_msg + mail_text

    return mail_text


def get_ip_addr():
    ip_addr = "Unknown"
    try:
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        s.connect(("8.8.8.8", 80))
        ip_addr = s.getsockname()[0]
    except Exception:
        logger.exception("Getting the Host IP Address failed")

    return ip_addr
