import logging

from nvsm_dshm.notifier.e_mail.state_machine import Email as EmailSM
from nvsm_dshm.policy import IPolicy
from nvsm_dshm.infra.helper import get_selected_severity
from nvsm_dshm.notifier.notifier_thread import NotifierTask

logger = logging.getLogger(__name__)


class EmailTask(NotifierTask):
    queue_size = 300
    name = 'EmailTask'

    def __init__(self):
        super(EmailTask, self).__init__()

    def put(self, alert):

        alert_filter_policy = IPolicy.factory('AlertFilter')

        if alert_filter_policy is not None:
            self.alert_severity = alert_filter_policy.get()['alert_severity']

        selected_alerts = get_selected_severity(self.alert_severity)

        for sev_level in selected_alerts:
            if alert['severity'] == sev_level:
                super(EmailTask, self).put(alert)
                return

        logger.info("Email:Notification is not processed because alert severity: {} not chosen in the policy".
                                                           format(alert['severity']))

    def run(self):
        while True:
            item = self.queue.get()

            # Batch all the alerts in the queue
            alerts = {}
            while True:
                key = item['component_id'] + '|' + item['alert_id']

                if key in list(alerts.keys()):
                    if item['severity'] == 'Cleared':
                        logger.debug("Alert notification for {}, {}, {} was dropped because it was cleared before the notification was sent.".format(
                            item['component_id'], item['alert_id'], item['event_time']))
                        alerts[key] = None
                else:
                    # No email notifications are sent when alerts are cleared.
                    if item['severity'] != 'Cleared':
                        alerts[key] = item
                self.queue.task_done()

                if not self.queue.empty():
                    item = self.queue.get()
                else:
                    batch = [
                        alert for key,
                        alert in list(alerts.items(
                        )) if alert is not None]

                    if batch:
                        EmailSM(batch).run()
                    break
