import time
import logging


from nvsm_dshm.notifier.pager_duty.state_machine import PagerDuty as PagerDutySM
from nvsm_dshm.notifier.notifier_thread import NotifierTask
from nvsm_dshm.policy import IPolicy
from nvsm_dshm.infra.helper import get_selected_severity
from nvsm_dshm.policy import IPolicy


logger = logging.getLogger(__name__)


EXECUTION_INTERVAL = 600  # PagerDutyTask's batch processing is triggered at most once every 10 minutes.
MIN_BATCH_SLEEP_TIME = 10 #This is to wait for a minimum time,this for batching the alerts.  


class PagerDutyTask(NotifierTask):
    queue_size = 300
    name = 'PagerDutyTask'

    def __init__(self, webserver, stage, version):
                 #jwt_filename  

        super(PagerDutyTask, self).__init__()
        self.webserver = webserver
        self.stage = stage
        self.version = version
        #self.jwt_filename = jwt_filename

        pagerduty_policy = IPolicy.factory('PagerDuty')
        if pagerduty_policy is not None:
            self.execution_interval = pagerduty_policy.get()['batch_interval']

        alert_filter_policy = IPolicy.factory('AlertFilter')
        if alert_filter_policy is not None:
            self.alert_severity = alert_filter_policy.get()['alert_severity']

    def put(self, alert):
        pagerduty_policy = None
        try:
            pagerduty_policy = IPolicy.factory('PagerDuty')
            if ((pagerduty_policy is not None) and (not pagerduty_policy.get()['enable'])):
                logger.info(
                   "Notification is not processed because PagerDuty policy is not enabled")
                return
        except Exception as excep:
            logger.error("Failed in getting PagerDuty policy, {}".format(str(excep)))

        alert_filter_policy = IPolicy.factory('AlertFilter')
        if alert_filter_policy is not None:
            self.alert_severity = alert_filter_policy.get()['alert_severity']

        selected_alerts = get_selected_severity(self.alert_severity)              

        for sev_level in selected_alerts:
            if alert['severity'] == sev_level:
                super(PagerDutyTask, self).put(alert)
                return

        logger.info("Notification is not processed because alert severity: {} not chosen in the policy".
                                                           format(alert['severity']))
        #super(PagerDutyTask, self).put(alert)

    def run(self):
        timestamp = None
        first_boot = True
        seconds_elapsed = 0

        while True:

            item = self.queue.get()

            if timestamp:
                seconds_elapsed = time.time() - timestamp
                if seconds_elapsed < self.execution_interval:
                    time.sleep(self.execution_interval - seconds_elapsed)
                else:
                    time.sleep(MIN_BATCH_SLEEP_TIME)

            pagerduty_policy = IPolicy.factory('PagerDuty')
            if pagerduty_policy is not None:
                self.execution_interval = pagerduty_policy.get()['batch_interval']
                logger.info(
                   "Alert batch interval set to {} seconds.".format(self.execution_interval))

            # Batch all the alerts in the queue
            # NOTE: The notifications in the queue preserve the chronology, but
            # while constructin the batch the chronology will be lost since the
            # alerts data structure used below is a dictionary and it does not
            # preserve order.
            alerts = {}
            while True:
                key = item['component_id'] + '|' + item['alert_id'] + '|' + item['event_time']

                if key in list(alerts.keys()):
                    if item['severity'] == 'Cleared':
                        logger.debug("Alert notification for {}, {}, {} was dropped because it was cleared before the notification was sent.".format(
                            item['component_id'], item['alert_id'], item['event_time']))
                        alerts[key] = None
                    else:
                        alerts[key] = item
                else:
                    alerts[key] = item

                self.queue.task_done()

                if timestamp is None and first_boot:
                    timestamp = time.time()
                    first_boot = False
                    seconds_elapsed = time.time() - timestamp

                    logger.info(
                       "Alert batch interval difference {} seconds.".format(self.execution_interval - seconds_elapsed))

                    if seconds_elapsed < self.execution_interval:
                        time.sleep(self.execution_interval - seconds_elapsed)

                if not self.queue.empty():
                    item = self.queue.get()
                else:
                    batch = []
                    batch_id = None
                    for key, alert in list(alerts.items()):
                        if not alert:
                            continue

                        if batch_id is None and alert['severity'] != 'Cleared':
                            batch_id = alert['event_time']

                        if alert['severity'] == 'Cleared':  # Cleared alerts at the back of the list
                            batch.append(alert)
                        else:  # New alerts at the front of the list
                            batch.insert(0, alert)

                    if batch:
                        for batch_item in batch:
                            if batch_id is None:
                                batch_id = batch_item['event_time']
                            batch_item['batch_id'] = batch_id
                    if batch:
                        timestamp = time.time()
                        PagerDutySM(
                            self.webserver,
                            self.stage,
                            self.version,
                            #self.jwt_filename,
                            batch).run()
                    break

