import os
import logging

import json
import requests
import datetime

logger = logging.getLogger(__name__)


PAGER_DUTY_VERSION_2 = 'https://events.pagerduty.com/v2/enqueue'

def to_json(notification):
    obj = {}

    obj['system_serial'] = notification['system_serial']
    obj['alert_id'] = notification['alert_id']
    obj['component_id'] = notification['component_id']
    obj['event_time'] = notification['event_time']
    obj['severity'] = notification['severity']
    obj['clear_time'] = notification['clear_time']
    obj['description'] = notification['description']
    obj['message_details'] = notification['message_details']
    obj['message'] = notification['message']
    obj['system_name'] = notification['system_name']
    obj['batch_id'] = notification['batch_id']

    return json.dumps([obj])


def create_page(notification,
                service_key,  
                diag_test=False,
                api_version="v2",
                time_out=60):
    header = {
         "Content-Type": "application/json"
    }

    de_dup_key = None

    alert_set = set(['system_serial','alert_id', 'component_id','event_time', 'message',
                      'severity','batch_id','clear_time','description','message_details', 'system_name'])

    if not (alert_set.issubset(set(notification.keys()))):
        logger.error("PAGER DUTY: Alert data not in the expected format.")
        return {'error': True}

    if not service_key:
        logger.error("PAGER DUTY: Service Key is empty.")
        return {'error': True}

    de_dup_key = notification['system_serial']+"|"+notification['alert_id']+"|"+ \
                 notification['component_id']+"|"+notification['event_time'] 

    severity   = "info"
    if notification['severity'] == "Critical":
        severity = "critical"

    if notification['severity'] == 'Warning':
        severity = "warning"

    action = "trigger"
    if notification['severity'] == 'Cleared':
        action = "resolve"


    json_data = to_json(notification)

    payload = { # Payload is built with the least amount of fields required to trigger an incident
                "routing_key" : service_key,
                "event_action": action,         
                "dedup_key"   : de_dup_key, 
                "payload"     : {
                                 "summary"       : notification['message'],
                                 "source"        : notification['system_serial'],
                                 "severity"      : severity,
                                 "timestamp"     : notification['batch_id'],
                                 "component"     : notification['component_id'],
                                 #"group"         : #get from alert
                                 #"class"         : #get from alert
                                 "custom_details":notification 
                                }
               }

    response = requests.post(PAGER_DUTY_VERSION_2,
                             data=json.dumps(payload),
                             headers=header,
                             timeout=time_out)

    if "routing_key" in payload:
        del payload["routing_key"]

    logger.debug("PAGER DUTY: data sent to PD:{}".format(json.dumps(payload)))

    if response and response.json()["status"] == "success":
        logger.debug("PAGER DUTY:Incident created in PagerDuty.")
        return {'error': False}

    res_txt = 'None' 
    if response:
        res_txt = response.text

    logger.error("PAGER DUTY:Error while creating Page {}".format(res_txt))
    return {'error': True}
