#!/usr/bin/python
# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

"""
System monitoring helper module
"""

import logging

from nvsm_dshm.thea import Client
from nvsm_dshm.thea import Endpoint
from nvsm_dshm.equipment import Equipment
from nvsm_dshm.ds import AlertsDataStore
from nvsm_dshm.equipment import Alert 
from nvsm_dshm.policy import IPolicy
from nvsm_dshm.infra import ErrCode as Err

logger = logging.getLogger(__name__)

# def process_container(obj, device_type, base_device_type):
#    """
#        Job to fetch the device_type container object and execute the rules
#        on the  object
#    """
#    logger.debug(
#        "Alert processing for device_type : " +
#        device_type +
#     " Enter")
#
#    if obj is None:
#        logger.error(
#            'JSON OBJ received from the event is None for {} '.format(
#                device_type))
#        return Err.ERR_EMPTY_JSON_OBJS
#
#    policy = IPolicy.factory(base_device_type)
#    logger.debug("Policy used {}".format(policy))
#
# Fetch the device type objects
#    json_obj = Client.get_prop_value(obj)
#    if json_obj is None:
#        logger.error(
#            'Invalid payload received,device_type{} is empty.'.format(
#                device_type))
#        return Err.ERR_INVALID_JSON_OBJ
#
# Fetch the alerts in the data store
#    data_store = AlertsDataStore.factory('thea_db', base_device_type)
#
#    container = EquipmentContainer.factory(device_type, json_obj)
#    device_map = container.get_device_presence_map()
#    for device in list(device_map.keys()):
#        if not policy.monitor(device):
#            continue
#
#        logger.debug("Checking device presence {}".format(device))
#
#        ret = data_store.fetch_alerts(device)
#        if ret['errored']:
#            logger.error(
#                "Unable to fetch alert data from {} for thea".format(device_type))
#            logger.error(
#                'Thea is in-accessible, waiting till connection is re-established')
#
#            return Err.ERR_CONN_REST_SRV
#
#        alerts = ret['alerts']
#
#        container.apply_rules(device,
#                              device_map[device],
#                              Endpoint().hostname(),
#                              Endpoint().serial(),
#                              alerts)
#
#        data_store.store_alerts(device,
#                                alerts)
#
#    logger.debug("Alert processing for device_type : " + device_type + " Exit")
#    return Err.SUCCESS


def process(obj, device_type, base_device_type, **kwargs):
    """
        Job to fetch the device_type object and execute the rules
        on the  object
    """
    logger.debug(
        "Alert processing for device_type : " +
        device_type +
        " Enter")

    if obj is None:
        logger.error(
            'JSON OBJ received from the event is None for {} '.format(
                device_type))
        return Err.ERR_EMPTY_JSON_OBJS

    policy = IPolicy.factory(base_device_type)
    logger.debug("Policy used {}".format(policy))

    # Fetch the device object
    json_obj = Client.get_prop_value(obj)
    if json_obj is None:
        logger.error(
            'Invalid payload received, device_type{} is empty.'.format(
                device_type))
        return Err.ERR_INVALID_JSON_OBJ

    # Fetch the alerts in the data store
    data_store = AlertsDataStore.factory('thea_db', base_device_type)

    device = Equipment.factory(device_type, json_obj,
                               Endpoint().hostname(),
                               Endpoint().serial(), **kwargs)

    if device is not None and policy.monitor(device.get_name()):
        logger.debug("Checking device {}".format(device.get_name()))

        ret = data_store.fetch_alerts(device.get_name())
        if ret['errored']:
            logger.error(
                "Unable to fetch alert data from {} for thea".format(device_type))
            logger.error(
                'Thea is in-accessible, waiting till connection is re-established')

            return Err.ERR_CONN_REST_SRV
        
        alerts = ret['alerts']

        device.apply_rules(device, alerts)

        data_store.store_alerts(device.get_name(), alerts)

    logger.debug("Alert processing for device_type : " + device_type + " Exit")

    return Err.SUCCESS
