#!/usr/bin/python
# Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

"""
NVLink handlers defined
"""

import sys
import json
import logging

from nvsm_dshm.system.handler.helper import process
from nvsm_dshm.infra import ErrCode as Err
from nvsm_dshm.infra import pa

logger = logging.getLogger(__name__)
this = sys.modules[__name__]

def gpuNVLink(gpu_id, name, error, error_count, lane_id):
    return {'Id':gpu_id, 'Name':name, 'Error':error, 'GpuId':gpu_id, 'Count':error_count, 'LaneId':lane_id}

def nvlink_health(obj):
    """
    NVLink Health handler

    Gpu NVLink Health json obj:
        {"0": {"0":[{"error":"crcflit", "errorcount":"123"}, {"error":"crcdata", "errorcount":"123"}]},
         "1": {"1":[{"error":"recovery", "errorcount":"123"}, {"error":"replay", "errorcount":"123"}]}}
    """

    if obj is None:
        logger.error('JSON OBJ received from the event is None for NVLink Health')
        return Err.ERR_EMPTY_JSON_OBJS

    health_payload = json.loads(obj)
    if health_payload is None:
        logger.error('JSON OBJ payload received from the event is None for NVLink Health')
        return Err.ERR_INVLAID_MQ_PAYLOAD

    nvlink_obj_lst = []
    for entity_id, health in health_payload.items():
        for error, count in health.items():
            lane_id = error[-1] # Represents lane id
            nvlink_obj = gpuNVLink(entity_id, 'GPU{}'.format(entity_id), error, count, lane_id)
            nvlink_obj_lst.append(nvlink_obj)

    for nvlink_obj in nvlink_obj_lst:
        process(json.dumps(nvlink_obj), 'NVLink', 'Gpu')

    return Err.SUCCESS
