#!/usr/bin/python
# Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

"""
NVSwitch handlers defined
"""

import sys
import json
import logging

from nvsm_dshm.system.handler.helper import process
from nvsm_dshm.infra import ErrCode as Err
from nvsm_dshm.infra import pa

logger = logging.getLogger(__name__)
this = sys.modules[__name__]

def nvswitch(nvswitch_id, name, error, sxid):
    return {'Id':nvswitch_id, 'Name':name, 'Error':error, 'NVSwitchId':nvswitch_id, 'SNo':sxid}

def nvswitch_nvlink(nvswitch_id, name, error, state):
    return {'Id':nvswitch_id, 'Name':name, 'Error':error, 'NVSwitchId':nvswitch_id, 'SNo':state}

def nvswitch_health(obj):
    """
    NVSwitch Health handler
    Health json obj:
        {"0": {"error":"fatal", "xids":["1234", "4321"]},
         "1": {"error":"nonfatal", "xids":["1234", "4321"]}}

    NVSwitch NVLink State Health json obj:
        {"0": {"nvlink0":{"state":"disabled"}, "nvlink1":{"state":"unknown"}},
         "1": {"nvlink0":{"state":"disabled"}, "nvlink1":{"state":"unknown"}}}
    """
    
    if obj is None:
        logger.error('JSON OBJ received from the event is None for NVSwitch Health')
        return Err.ERR_EMPTY_JSON_OBJS

    health_payload = json.loads(obj)
    if health_payload is None:
        logger.error('JSON OBJ payload received from the event is None for NVSwitch Health')
        return Err.ERR_INVLAID_MQ_PAYLOAD

    nvswitch_obj_lst = []
    for nvswitch_id, health in health_payload.items():
        for error_type, s in health.items():
            if "nvlink" in error_type.lower():
                nvswitch_obj = nvswitch_nvlink(nvswitch_id, 'NVSwitch{}'.format(nvswitch_id), error_type, s)
            else:
                nvswitch_obj = nvswitch(nvswitch_id, 'NVSwitch{}'.format(nvswitch_id), error_type, s)
            nvswitch_obj_lst.append(nvswitch_obj)

    for nvswitch_obj in nvswitch_obj_lst:
        process(json.dumps(nvswitch_obj), 'NVSwitch', 'NVSwitch')

    return Err.SUCCESS
