# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

import time
import json
import yaml

# A placeholder for global defined configurations used across the NVSM Health

# Timestamp for nvsm-apis to know the stale messages
timestamp = ""

# Any task specific configurations
# Network Ping Settings
check_net_ping_count = 4
check_net_ping_timeout = 5

# Manufacturer ID mapped to name
nvidia_manufacturer_id = '5703'
quanta_manufacturer_id = '7244'
gds_cuda_versions = ["11.4", "11.3", "11.2", "11.1", "11.0", "10.2", "10.1"]


# The USB sysfs path
sys_usb = '/sys/bus/usb/devices/'

# The DMI system vendor sysfs path
sys_vendor = '/sys/devices/virtual/dmi/id/sys_vendor'

# The DMI product name sysfs path
sys_product_name = '/sys/devices/virtual/dmi/id/product_name'

# The DMI BIOS version sysfs path
sys_bios_version = '/sys/devices/virtual/dmi/id/bios_version'

# etc rel file template
etc_rel_file = '/etc/{}'

# Default timeout in seconds for subprocess.run to expire
default_timeout = 300

display_columns = 80
# 9 is the length of the largest health label string 'Unhealthy'
# 1 is for the space after the dots and between the dots and status
# 1 is to maintain identical output with previous versions
display_width = display_columns - 9 - 1 - 1

# Required NVIDIA driver version to support nvlink status
nvidia_driver_version = '384.98'

# List of result messages

# List of success messages

# List of error messages
pci_device_changed_str = "PCI register {} has value {} when {} was expected"

gpus_pci_device_missing_str = "Missing GPU at PCI address {}"
vgas_pci_device_missing_str = "Missing VGA Controller at PCI address {}"
ib_controllers_pci_device_missing_str = 'Missing InfiniBand controller at PCI address "{}"'
pcie_switches_pci_device_missing_str = 'Missing PCIe switch at PCI address "{}"'
nvswitch_pci_device_missing_str = 'Missing NVSwitch controller at PCI address "{}"'
ethernet_controllers_pci_device_missing_str = 'Missing Ethernet controller at PCI address "{}"'
disk_controllers_pci_device_missing_str = 'Missing disk controller at PCI address "{}"'
gpu_total_retired_pages_pending_error = "Reboot the system to blacklist GPU pages flagged for retirement. See: http://docs.nvidia.com/deploy/dynamic-page-retirement/index.html#blacklisting"
gpu_total_retired_pages_count_error = "Observed {.0f} retired pages ({} SBE; {} DBE) on GPU {}, exceeding threshold of {.0f} retired pages."

# List of warning messages
nvsm_health_unhealthy_message = "Problem detected.\n\n1. Please run 'sudo nvsm dump health'\n2. Please open a case with NVIDIA Enterprise Support at this address https://nvid.nvidia.com/dashboard/\n3. Attach the log file from {}"

# List of info messages
blacklist_recommendations_info_str = "Check DCGM for GPU blacklist recommendations"
blacklist_recommendations_instant_info_str = "Quick health check of GPU using DCGM"
health_check_result_str = "{} out of {} checks are {}"
health_status_str = "Overall system status is {}\n"
nvme_info_str = "Verify installed NVMe devices"
ipmitool_info_firmware_revision_str = "BMC Firmware Revision [{0}]"
dimms_info_str = "Verify installed DIMM memory sticks"
gpus_info_str = "Verify installed GPU's"
vgas_info_str = "Verify installed VGA Controllers"
ib_controllers_info_str = "Verify installed InfiniBand controllers"
pcie_switches_info_str = "Verify PCIe switches"
nvswitch_info_str = "Presence of NVSwitch controllers on PCI bus"
ethernet_controllers_info_str = "Verify Ethernet controllers"
ethernet_controller_link_info_str = {'width': '{name} Ethernet link width [{bdf}][x{width}]',
                                     'speed': '{name} Ethernet link speed [{bdf}][{speed}]'}
gpu_link_info_str = {'width': 'GPU link width [{bdf}][x{width}]',
                     'speed': 'GPU link speed [{bdf}][{speed}]'}
ib_controller_link_info_str = {'width': 'InfiniBand controller link width [{bdf}][x{width}]',
                               'speed': 'InfiniBand controller link speed [{bdf}][{speed}]'}
nvme_link_info_str = {'width': 'NVMe link width [{bdf}][x{width}]',
                      'speed': 'NVMe link speed [{bdf}][{speed}]'}
disk_controllers_info_str = "Verify disk controllers"
nvidia_driver_version_info_str = "NVIDIA Driver Version"
nvlink_speed_info_str = 'Checking NVLink speed [GPU{} [{}] Link {}][{}]'
gpu_total_retired_pages_count_str = "Total retired page count [GPU {gpu_index}][{pages} retired pages]"
gpu_total_retired_pages_pending_str = "Retired pages pending [GPU {gpu_index}][{pages}]"
gpu_inforom_version_str = "Inforom Storage Version [GPU{gpu_index} [{bdf}]]"
gpu_vbios_version_str = "VBIOS Version [GPU{gpu_index} [{bdf}]]"

# List of command messages
nvme_command_str = "Checking output of 'nvme list' for expected NVMe devices"
dimms_command_str = "Checking output of 'dmidecode' for expected DIMM's"
gpus_command_str = "Checking output of 'lspci' for expected GPU's"
vgas_command_str = "Checking output of 'lspci' for expected VGA Controllers"
ib_controllers_command_str = "Checking output of 'lspci' for expected InfiniBand controllers"
pcie_switches_command_str = "Checking output of 'lspci' for expected PCIe switches"
nvswitch_command_str = "Checking output of 'lspci' for expected NVSwitch controllers"
ethernet_controllers_command_str = "Checking output of 'lspci' for expected Ethernet controllers"
disk_controllers_command_str = "Checking output of 'lspci' for expected disk controllers"
gpu_direct_topology_command_str = "Checking GPUDirect topology against the output of\n'nvidia-smi topo --matrix'"
gpu_p2p_topology_command_str = "Checking GPUs p2p topology against the output of\n'nvidia-smi topo -p2p rw'"
fru_command_str = "Checking output of 'ipmitool fru print' and 'dmidecode' for FRU serial numbers consistency"
vbios_command_str = "Checking output of 'nvidia-smi' for GPUs vbios version consistency"
mlx_fw_ver_cmd_str = "Checking output of 'mlxfwmanager' for Mellanox device firmware version consistency"

nvsm_config_file = None


def read_nvsm_config_file():
    global nvsm_config_file
    if nvsm_config_file != None:
        return nvsm_config_file
    with open('/etc/nvsm/nvsm.config', 'r') as reader:
        nvsm_config_file = None
        valid_json = True
        try:
            nvsm_config_file = json.loads(reader)
        except:
            valid_json = False
            if not valid_json:
                nvsm_config_file = yaml.safe_load(reader)
        return nvsm_config_file
    return None


def get_nvsm_health_header():
    fmt = '\n\nInfo\n----\n'
    fmt += 'Timestamp:\t{0}\n'.format(time.strftime('%c %z'))
    # Print both Log and Viewer version if needed
    try:
        from nvsmhealth import version
        log_version = version.NVSMHEALTH_VERSION
    except:
        log_version = 'unknown version'
    fmt += 'Version:\t{0}'.format(log_version)
    fmt += '\n'
    fmt += '\nChecks\n------'
    return fmt
