# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

import sys
from collections import defaultdict

class TaskDependencyGraph:
    def __init__(self):
        # Dictionary containing adjacency list for dependency graph tasks
        self.__graph = defaultdict(list)
        self.__visited = {}
        self.__order = []

    def getOrder(self):
        return self.__order

    # Function to add a dependency between tasks
    def addTaskDependency(self, parent_task, task):
        self.__graph[parent_task].append(task)

    # Recursive function used by taskTopologicalSort
    def __taskTopologicalSort(self, task):
        # Mark the current task as visited.
        self.__visited[task] = True
        # Recur for all the tasks dependent on this task
        for dependent_task in reversed(sorted(self.__graph[task], key=lambda t: t.getName())):
            if self.__visited[dependent_task] == False:
                self.__taskTopologicalSort(dependent_task)
        # Store the current task into order in LIFO order
        self.__order.insert(0, task)

    # Function to perform Tasks Topological Sort
    def taskTopologicalSort(self, tasks):
        # Mark all tasks as not visited
        for task in tasks:
            self.__visited[task] = False
        # Start sorting tasks
        for task in reversed(sorted(tasks, key=lambda t: t.getName())):
            if self.__visited[task] == False:
                self.__taskTopologicalSort(task)

    def printSortedGraphviz(self, file=sys.stdout):
        prev = None
        print(
            'digraph G {\n' \
            '  rankdir=BT;',
            file=file)
        for task in self.__order:
            print('  "{node}";'.format(node=task.getName()))
            if prev != None:
                 print('  "{first}" -> "{second}";'.format(first=task.getName(), second=prev.getName()), file=file)
            prev = task
            
        print('}', file=file)
