# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

import logging
import os
import sys 
from importlib import import_module

# Automatically import all Python modules under this directory (and its subdirectories)
__all__ = []
modules_dir = os.path.dirname(__file__)
with os.scandir(path=modules_dir) as i:
    for entry in i:
        if entry.name.startswith('.'):
            continue
        if entry.name.startswith('_'):
            continue
        if entry.is_dir():
            module_name = entry.name
        elif entry.is_file() and entry.name.endswith('.py'):
            module_name = os.path.splitext(entry.name)[0]
        else:
            continue
        __all__.append(module_name)

            
# Import all modules, taking care to resolve inter-module dependencies
import copy, importlib
__remaining_imports = copy.copy(__all__)
__next_remaining_imports = []
while True:
    for module_name in __remaining_imports:
        try:
            globals()[module_name] = importlib.import_module('.{}'.format(module_name), __name__)
        except AttributeError:
            __next_remaining_imports.append(module_name)
    if not __next_remaining_imports:
        break  # done
    if len(__next_remaining_imports) == len(__remaining_imports):
        logging.error('Error resolving dependencies among NVSMHealth modules: {}'.format(__remaining_imports))
        # Force a stack trace pointing to the dependency problem
        for module_name in __remaining_imports:
            importlib.import_module('.{}'.format(module_name), __name__)
        sys.exit(1)
    logging.info('Note: Inter-module dependencies detected in: {}'.format(__next_remaining_imports))
    __remaining_imports = __next_remaining_imports
    __next_remaining_imports = []

