# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from nvsmhealth import modules, tasks

__all__ = [
    'run_ipmitool',
    'check_ipmitool_working'
]

run_ipmitool = tasks.RunCommand(
        args=['ipmitool']) \
    .title('''Run the ipmitool command''') \
    .describe('''
            This simply runs the "ipmitool" command to make sure that ipmitool
            is able to access the BMC (baseboard management controller).''') \
    .depends(modules.common.check_superuser_privileges)

check_ipmitool_working = tasks.CheckExitStatus(run_ipmitool) \
    .title('''Check that the ipmitool command is working''') \
    .describe('''
            This checks the exit status of the "ipmitool" command. If the
            ipmitool command runs with successful exit status, then this is a
            good indication that ipmitool was able to communicate with the BMC
            (baseboard management controller).''')
