# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from nvsmhealth import modules, tasks

__all__ = [
    'check_superuser_privileges'
]

class CheckSuperuserPrivileges(tasks.ICheck):
    def __init__(self):
        super(CheckSuperuserPrivileges, self).__init__()
        # TODO Use ICheck check_result attribute
        self.__check_result = {'healthy':0, 'unhealthy':0, 'unknown':0, 'informational':0}

    # TODO Use ICheck getResult method
    def getResult(self):
        return self.__check_result

    def run(self):
        import os
        # TODO: How should classes implementing ICheck communicate
        #       health check results?
        if os.geteuid() != 0:
            pass
check_superuser_privileges = CheckSuperuserPrivileges() \
    .title('''Check for superuser privileges''') \
    .describe('''
            This checks that NVSM Health is running with an effective user ID of
            0, which indicates superuser or "root" privileges. Many NVSM Health
            checks require superuser privileges in order to run certain
            privileged commands or access privileged log files.''')

class VariantRef:
    """
        Blocks or records can either be represented by a Python dictionary, a
        list of strings, or a single attribute string. This class allows us to
        pass any one of these.
    """
    def __init__(self):
        self.dict = None
        self.array = None
        self.attribute = None

    def value(self):
        if self.dict != None:
            return self.dict
        if self.array != None:
            return self.array
        if self.attribute != None:
            return self.attribute
        return None

'''
The "almost equal" check operation verifies that an event numerical
value is within a tolerance of a reference threshold, specifically,
threshold + tolerance >= value >= threshold - tolerance.
'''
def almost_equal(value, threshold, tolerance):
    return (threshold + tolerance >= value) and \
            (value >= threshold - tolerance)

