# # Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
# #
# # NVIDIA CORPORATION and its licensors retain all intellectual property
# # and proprietary rights in and to this software, related documentation
# # and any modifications thereto.  Any use, reproduction, disclosure or
# # distribution of this software and related documentation without an express
# # license agreement from NVIDIA CORPORATION is strictly prohibited.

import logging
from nvsmhealth import modules, tasks, config
from nvsmhealth.modules.dcs_modules.dcc_health_api import run_dcc_health_api
# import re

__all__ = [
    'check_dcc_ecu_health',
    'check_dcc_ecu_hardware_health',
    'check_dcc_ecu_application_health',
    'check_dcc_ecu_tegraA_health',
    'check_dcc_ecu_tegraB_health',
    'check_dcc_ecu_tegraA_storage_health',
    'check_dcc_ecu_tegraB_storage_health',
]

class CheckDccEcuHealth(tasks.ITask):
    def __init__(self, run_dcc_health_api_task):
        super().__init__()
        self.__run_dcc_health_api_task = run_dcc_health_api_task
        self.__output = None

    def getOutput(self):
        return self.__output

    def run(self):
        json_output = self.__run_dcc_health_api_task.getOutput()
        if json_output != None:
            try:
                self.__output = json_output['ecu_health']
                #print(self.__output)
            except:
                self.__output = None
                #self.addUnknown()
                return
        #self.addHealthy()

check_dcc_ecu_health = CheckDccEcuHealth(run_dcc_health_api) \
    .title('''Drive Constellation: Check DCC ECU health''') \
    .depends(run_dcc_health_api) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))


class CheckDccEcuHardwareHealth(tasks.ITask):
    def __init__(self, check_dcc_ecu_health):
        super().__init__()
        self.__run_dcc_ecu_health_api_task = check_dcc_ecu_health
        self.__output = None

    def getOutput(self):
        return self.__output

    def run(self):
        json_output = self.__run_dcc_ecu_health_api_task.getOutput()
        if json_output != None:
            try:
                self.__output = json_output['ecu_hardware_health']
                #print(self.__output)
            except:
                self.__output = None
                #self.addUnknown()
                return
        #self.addHealthy()

check_dcc_ecu_hardware_health = CheckDccEcuHardwareHealth(check_dcc_ecu_health) \
    .title('''Drive Constellation: Check DCC ECU Hardware health''') \
    .depends(check_dcc_ecu_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccEcuApplicationHealth(tasks.ITask):
    def __init__(self, check_dcc_ecu_health):
        super().__init__()
        self.__run_dcc_ecu_health_api_task = check_dcc_ecu_health
        self.__output = None

    def getOutput(self):
        return self.__output

    def run(self):
        json_output = self.__run_dcc_ecu_health_api_task.getOutput()
        if json_output != None:
            try:
                self.__output = json_output['ecu_application_health']
            except:
                self.__output = None
                return

check_dcc_ecu_application_health = CheckDccEcuApplicationHealth(check_dcc_ecu_health) \
    .title('''Drive Constellation: Check DCC ECU Application health''') \
    .depends(check_dcc_ecu_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))


class CheckDccEcuTegraAHealth(tasks.ICheck):
     def __init__(self, check_dcc_ecu_hardware_health):
        super().__init__()
        self.__run_dcc_hardware_health = check_dcc_ecu_hardware_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        self.addCheckMessage("Checking DCC ECU TegraA Hardware health")
        #import pdb
        #pdb.set_trace()
        json_output = self.__run_dcc_hardware_health.getOutput()
        if json_output != None:
            try:
                dcc_tegraA_health = json_output['tegraA_health']
                if dcc_tegraA_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                    self.addCheckMessage(dcc_tegraA_health['test_information'])

            except Exception as e:
                print("Error fetching ecu TegraA health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_ecu_tegraA_health = CheckDccEcuTegraAHealth(check_dcc_ecu_hardware_health) \
    .title('''Drive Constellation: Check DCC ECU TegraA Health''') \
    .depends(check_dcc_ecu_hardware_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccEcuTegraBHealth(tasks.ICheck):
     def __init__(self, check_dcc_ecu_hardware_health):
        super().__init__()
        self.__run_dcc_hardware_health = check_dcc_ecu_hardware_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        self.addCheckMessage("Checking DCC ECU TegraB Hardware health")
        #import pdb
        #pdb.set_trace()
        json_output = self.__run_dcc_hardware_health.getOutput()
        if json_output != None:
            try:
                dcc_tegraB_health = json_output['tegraB_health']
                if dcc_tegraB_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                    self.addCheckMessage(dcc_tegraB_health['test_information'])

            except Exception as e:
                print("Error fetching ecu TegraB health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_ecu_tegraB_health = CheckDccEcuTegraBHealth(check_dcc_ecu_hardware_health) \
    .title('''Drive Constellation: Check DCC ECU TegraB Health''') \
    .depends(check_dcc_ecu_hardware_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccEcuTegraAStorageHealth(tasks.ICheck):
     def __init__(self, check_dcc_ecu_application_health):
        super().__init__()
        self.__run_dcc_ecu_application_health = check_dcc_ecu_application_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        self.addCheckMessage("Checking DCC ECU TegraA Storage health")
        #import pdb
        #pdb.set_trace()
        json_output = self.__run_dcc_ecu_application_health.getOutput()
        if json_output != None:
            try:
                dcc_tegraB_health = json_output['tegraA_health']
                if dcc_tegraB_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                self.addCheckMessage(dcc_tegraB_health['test_information'])

            except Exception as e:
                print("Error fetching ecu TegraA health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_ecu_tegraA_storage_health = CheckDccEcuTegraAStorageHealth(check_dcc_ecu_application_health) \
    .title('''Drive Constellation: Check DCC ECU TegraA Storage Health''') \
    .depends(check_dcc_ecu_application_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccEcuTegraBStorageHealth(tasks.ICheck):
     def __init__(self, check_dcc_ecu_application_health):
        super().__init__()
        self.__run_dcc_ecu_application_health = check_dcc_ecu_application_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        self.addCheckMessage("Checking DCC ECU TegraB Storage health")
        #import pdb
        #pdb.set_trace()
        json_output = self.__run_dcc_ecu_application_health.getOutput()
        if json_output != None:
            try:
                dcc_tegraB_health = json_output['tegraB_health']
                if dcc_tegraB_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                self.addCheckMessage(dcc_tegraB_health['test_information'])

            except Exception as e:
                print("Error fetching ecu TegraB health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_ecu_tegraB_storage_health = CheckDccEcuTegraBStorageHealth(check_dcc_ecu_application_health) \
    .title('''Drive Constellation: Check DCC ECU TegraB Storage Health''') \
    .depends(check_dcc_ecu_application_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))
