# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.
import logging
from nvsmhealth import modules, tasks, config
from nvsmhealth.modules.dcs_modules.dcc_health_api import run_dcc_health_api 


__all__ = [
    'check_dcc_hardware_health',
    'check_dcc_ethernet_health',
    'check_dcc_fan_health',
    'check_dcc_can_health',
    'check_dcc_usb_health',
    'check_dcc_gpu_health',
]

class CheckDccHardwareHealth(tasks.ITask):
    def __init__(self, run_dcc_health_api_task):
        super().__init__()
        self.__run_dcc_health_api_task = run_dcc_health_api_task
        self.__output = None
  
    def getOutput(self):
        return self.__output

    def run(self):
        json_output = self.__run_dcc_health_api_task.getOutput()
        if json_output != None:
            try:
                self.__output = json_output['dcc_hardware_health']
                #print(self.__output)
            except:
                self.__output = None 
                #self.addUnknown()
                return
        #self.addHealthy()

check_dcc_hardware_health = CheckDccHardwareHealth(run_dcc_health_api) \
    .title('''Drive Constellation: Check DCC Hardware health''') \
    .depends(run_dcc_health_api) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccEthernetHealth(tasks.ICheck):
     def __init__(self, check_dcc_hardware_health):
        super().__init__()
        self.__run_dcc_hardware_health = check_dcc_hardware_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        self.addCheckMessage("Checking DCS Hardware health")
        #import pdb
        #pdb.set_trace()
        json_output = self.__run_dcc_hardware_health.getOutput()
        if json_output != None:
            try:
                dcc_ethernet_health = json_output['dcc_ethernet_health']
                if dcc_ethernet_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                    self.addCheckMessage(dcc_ethernet_health['test_information'])

            except Exception as e:
                logging.debug("Error fetching ethernet health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_ethernet_health = CheckDccEthernetHealth(check_dcc_hardware_health) \
    .title('''Drive Constellation: Check DCC Ethernet Health''') \
    .depends(check_dcc_hardware_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccFanHealth(tasks.ICheck):
     def __init__(self, check_dcc_hardware_health):
        super().__init__()
        self.__run_dcc_hardware_health = check_dcc_hardware_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        json_output = self.__run_dcc_hardware_health.getOutput()
        if json_output != None:
            try:
                dcc_fan_health = json_output['dcc_fan_health']
                if dcc_fan_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                    self.addCheckMessage(dcc_fan_health['test_information'])
                    return
            except Exception as e:
                logging.debug("Error fetching ethernet health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_fan_health = CheckDccFanHealth(check_dcc_hardware_health) \
    .title('''Drive Constellation: Check DCC Fan Health''') \
    .depends(check_dcc_hardware_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccCanHealth(tasks.ICheck):
     def __init__(self, check_dcc_hardware_health):
        super().__init__()
        self.__run_dcc_hardware_health = check_dcc_hardware_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        json_output = self.__run_dcc_hardware_health.getOutput()
        if json_output != None:
            try:
                dcc_can_health = json_output['dcc_can_health']
                if dcc_can_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                    self.addCheckMessage(dcc_can_health['test_information'])

            except Exception as e:
                logging.debug("Error fetching can health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_can_health = CheckDccCanHealth(check_dcc_hardware_health) \
    .title('''Drive Constellation: Check DCC CAN Health''') \
    .depends(check_dcc_hardware_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccUsbHealth(tasks.ICheck):
     def __init__(self, check_dcc_hardware_health):
        super().__init__()
        self.__run_dcc_hardware_health = check_dcc_hardware_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        json_output = self.__run_dcc_hardware_health.getOutput()
        if json_output != None:
            try:
                dcc_usb_health = json_output['dcc_usb_health']
                if dcc_usb_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                    self.addCheckMessage(dcc_usb_health['test_information'])

            except Exception as e:
                logging.debug("Error fetching usb health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_usb_health = CheckDccUsbHealth(check_dcc_hardware_health) \
    .title('''Drive Constellation: Check DCC USB Health''') \
    .depends(check_dcc_hardware_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccGpuHealth(tasks.ICheck):
     def __init__(self, check_dcc_hardware_health):
        super().__init__()
        self.__run_dcc_hardware_health = check_dcc_hardware_health
        self.__output = ""

     def getOutput(self):
        return self.__output

     def run(self):
        json_output = self.__run_dcc_hardware_health.getOutput()
        if json_output != None:
            try:
                dcc_gpu_health = json_output['dcc_gpu_health']
                if dcc_gpu_health['test_result']  == "Healthy":
                    self.addHealthy()
                else:
                    self.addUnHealthy()
                    self.addCheckMessage(dcc_gpu_health['test_information'])

            except Exception as e:
                logging.debug("Error fetching gpu health info: {}".format(e))
                self.addUnknown()
                return
        self.addHealthy()

check_dcc_gpu_health = CheckDccGpuHealth(check_dcc_hardware_health) \
    .title('''Drive Constellation: Check DCC GPU Health''') \
    .depends(check_dcc_hardware_health) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))
