from nvsmhealth import modules, tasks, config
import logging
import requests
import json

__all__ = [
#    'run_nvpm_dcc_health_api',
    'run_dcc_health_api',
    'check_dcc_info',
    'check_ecu_info',
]

#args=['docker', 'exec', '-it', 'nvpm', print_file ], shell=True) \
#dcc_health_command = "docker exec -it nvpm bash -c \"python -c 'from app.main import get_nvsm_dcc_health; print(get_nvsm_dcc_health())'\""


NVPM_SERVER_IP = '127.0.0.1' 
NVPM_SERVER_PORT = '9101'
dcc_health_api = '/v1/platform-health'
_TIMEOUT = 10

class NvpmHealthServer():
    def __init__(self, ipaddr, port, jwt_file=None,
                 ca_cert_file=None):
        self.ip_addr = ipaddr
        self.port = port
        self.jwt_file = jwt_file
        self.ca_cert_file = ca_cert_file

    def getOutput(self, url_path, access_type, data=None):
        """
        Issues http request and returns the response
        """
        if not url_path:
            return None
        
        if access_type == "GET":
            try:
                url_prefix = 'http://' + self.ip_addr + ':' + self.port
                ret = requests.get(url=url_prefix + url_path,
                                   timeout=_TIMEOUT)
                if ret.status_code == 200:
                    return ret.text
                else:
                    print("HTTP GET %s returned %d" %
                                 (url_prefix + url_path, ret.status_code))
                    return None
            except requests.exceptions.RequestException as excep:
                print('HTTP GET failed: {}'.format(url_prefix+url_path))
            return None


run_nvpm_dcc_health_api = NvpmHealthServer(NVPM_SERVER_IP, NVPM_SERVER_PORT)


class NvpmGetDccHealth(tasks.ITask):
    def __init__(self, run_nvpm_dcc_health_api_task):
        super().__init__()
        self.dcc_health_api_output = None
        self.__run_nvpm_dcc_health_api_task = run_nvpm_dcc_health_api_task
    
    def getOutput(self):
        return self.dcc_health_api_output

    def decodeDccHealthOutput(self, output):
        try:
            json_obj = json.loads(output)
        except Exception as e:
            print("Error decoding JSON:{}".format(e))
        self.dcc_health_api_output = json_obj
        return

    def run(self):
        if self.dcc_health_api_output is None:
            output = self.__run_nvpm_dcc_health_api_task.getOutput(dcc_health_api,"GET")
            if (output is not None):
                try:
#                    print("Container OP:{}".format(output))
                    self.decodeDccHealthOutput(output)
                    if self.dcc_health_api_output == "":
                        print("Unable to decode DCC Health Output")
                        return
#                    print("Decoded OP:{}".format(self.dcc_health_api_output))
                except Exception as e:
                    print("DCC Health unable to decode JSON {}".format(e)) 
            else:
                print("DCC Health Output is None")
                self.dcc_health_api_output = None
        else:
            return self.dcc_health_api_output

#    .depends(run_nvpm_dcc_health_api) \
run_dcc_health_api = NvpmGetDccHealth(run_nvpm_dcc_health_api) \
    .title('Run nvpm dcc health command') \
    .describe('''Fetch nvpm DCC API Info.''') \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckDccInfo(tasks.ICheck):
    def __init__(self, run_dcc_health_api_task):
        super().__init__()
        self.__run_dcc_health_api_task = run_dcc_health_api_task
        self.__output = None
  
    def getOutput(self):
        return self.__output

    def run(self):
        json_output = self.__run_dcc_health_api_task.getOutput()
        if json_output != None:
            try:
                dcc_info = json_output['dcc_info']
                self.addHealthy()
                for key, value in dcc_info.items():
                    key = key[0:].replace('_', ' ')
                    key = key[0:].title()
                    self.send("{:20} : {:20}".format(key, value))
            except Exception as e:
                self.addUnHealthy()
                logging.debug("Error fetching dcc info: {}".format(e))
                self.__output = None 
                #self.addUnknown()
                return
        #self.addHealthy()

check_dcc_info = CheckDccInfo(run_dcc_health_api) \
    .title('''Drive Constellation: Get DCC Info''') \
    .depends(run_dcc_health_api) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))

class CheckEcuInfo(tasks.ICheck):
    def __init__(self, run_dcc_health_api_task):
        super().__init__()
        self.__run_dcc_health_api_task = run_dcc_health_api_task
        self.__output = None

    def getOutput(self):
        return self.__output

    def run(self):
        json_output = self.__run_dcc_health_api_task.getOutput()
        if json_output != None:
            try:
                ecu_info = json_output['ecu_info']
                self.addHealthy()
                for key, value in ecu_info.items():
                    key = key[0:].replace('_', ' ')
                    key = key[0:].title()
                    self.send("{:20} : {:20}".format(key, value))
            except Exception as e:
                self.addUnHealthy()
                logging.debug("Error fetching dcc info: {}".format(e))
                self.__output = None
                #self.addUnknown()
                return
        #self.addHealthy()

check_ecu_info = CheckEcuInfo(run_dcc_health_api) \
    .title('''Drive Constellation: Get ECU Info''') \
    .depends(run_dcc_health_api) \
    .parameters('enable_dcv_checks') \
    .parameters('enable_cgx_sm_checks') \
    .predicate(lambda: (modules.parameter.parameters.getResult().get('enable_dcv_checks') or modules.parameter.parameters.getResult().get('enable_cgx_sm_checks')))


#Application Config

#DCC ECU

# ECU Storage
