# Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from nvsmhealth import tasks, platforms, config
from nvsmhealth.modules.dump.dcs_logs import pegasus_syslog, pegasus_dbglog
from nvsmhealth.modules.dump.gds_log import gds_collect

__all__ = [
    "gds_collect",
    "acpi_video_info",
    "application_dump",
    "apt_log",
    "apt_preferences_nvidia",
    "apt_sources",
    "apt_sources_list_d",
    "bash",
    "bash_hello_world",
    "bmc_sel_log",
    "cmdline",
    "collect_nvsm",
    "collectd_log",
    "cosmos_log",
    "cpuinfo",
    "date",
    "date_utc",
    "dcgmi_nvlink",
    "dcc_ipmitool_sel_writeraw",
    "debian_release",
    "debian_version",
    "df",
    "dgx_release",
    "dmesg",
    "dmesg_log",
    "dmidecode",
    "docker_info",
    "docker_ps",
    "docker_volume_netshare_log",
    "dpkg_list",
    "dpkg_verify",
    "dshm_log",
    "nvsm_log",
    "etc_netplan",
    "ethtool",
    "fabricmanager_log",
    "fedora_release",
    "fscache_stats",
    "gcc",
    "gds_check",
    "gds_stats",
    "gds_stack_trace",
    "gentoo_release",
    "glxinfo",
    "gpp",
    "hca_self_test",
    "ibstat",
    "ibstatus",
    "ibdev2netdev",
    "ibv_devinfo",
    "installer_syslog",
    "interrupts",
    "iomem",
    "ip_addr_show",
    "ip_link_show",
    "ip_route_show",
    "ipmitool_bmc_info",
    "ipmitool_chassis_status",
    "ipmitool_fru",
    "ipmitool_lan_print",
    "ipmitool_power_led_status",
    "ipmitool_raw",
    "ipmitool_raw_dgxa100",
    "ipmitool_sdr",
    "ipmitool_sdr_info",
    "ipmitool_sdr_dump",
    "ipmitool_sel_elist",
    "ipmitool_sel_info",
    "ipmitool_sel_list",
    "ipmitool_sel_time_get",
    "ipmitool_sel_writeraw",
    "ipmitool_user_list_1",
    "issue",
    "java",
    "java_hello_world",
    "kern_log",
    "kernel_log",
    "ldconfig",
    "lib_netplan",
    "lsb_release",
    "lsblk",
    "lsblk_discard",
    "lsblk_topology",
    "lscpu",
    "lshw",
    "lslocks",
    "lsmod",
    "lspci",
    "lspci_plain",
    "lspci_tree",
    "lsusb",
    "lsusb_tree",
    "lsusb_verbose",
    "mandrake_release",
    "mdadm_detail",
    "mdadm_examine",
    "mdstat",
    "meminfo",
    "mesos_master_error",
    "mesos_master_fatal",
    "mesos_master_info",
    "mesos_master_warning",
    "mesos_slave_error",
    "mesos_slave_fatal",
    "mesos_slave_info",
    "mesos_slave_warning",
    "messages",
    "mlxcables",
    "mlx_fetch_arm_log",
    "modinfo",
    "modules",
    "monit_log",
    "mount",
    "mtrr",
    "network_interfaces",
    "network_interfaces_d",
    "nfsfs_servers",
    "nfsfs_volumes",
    "nginx_log",
    "ntpq",
    "numactl",
    "nvcc",
    "nvidia_address_text",
    "nvidia_application_profiles1",
    "nvidia_application_profiles2",
    "nvidia_application_profiles3",
    "nvidia_debugdump",
    "nvidia_dkms_log",
    "nvidia_driver_gpu_information",
    "nvidia_driver_gpu_registry",
    "nvidia_driver_ko",
    "nvidia_driver_params",
    "nvidia_driver_registry",
    "nvidia_driver_version",
    "nvidia_driver_warnings",
    "nvidia_fs_stats",
    "nvidia_fs_peer_distance",
    "nvidia_fs_peer_affinity",
    "nvidia_fw_log",
    "nvidia_installer_log",
    "nvidia_settings",
    "nvidia_smi",
    "nvidia_smi_nvlink",
    "nvidia_smi_query",
    "nvidia_smi_query_unit",
    "nvidia_smi_topo",
    "nvidia_smi_xml",
    "nvidia_uninstall_log",
    "nvidia_dcshwapikey_conf",
    "nvidia_dcshwapikey_license",
    "nvidia_vm_health_check_show",
    "nvidia_vm_image_show",
    "nvidia_vm_resources_show",
    "nvme_list",
    "nvme_logs",
    "nvsm_health_show_debug",
    "nvsm_show",
    "nvsm_show_alerts",
    "nvsm_show_debug",
    "ofed_info",
    "pci",
    "perl",
    "perl_hello_world",
    "ping_compute",
    "printenv",
    "ps",
    "ps_aux",
    "psu_info_dgx1",
    "python",
    "python_hello_world",
    "redhat_release",
    "redhat_version",
    "release",
    "remote_bmc_sel_log",
    "run_netplan",
    "service_cachefilesd_status",
    "service_status_all",
    "slackware_release",
    "slackware_version",
    "smartctl",
    "smartctl_scan",
    "storcli_cmds",
    "sun_release",
    "sysctl",
    "syslog",
    "system_map",

    "td_agent_log",
    "timedatectl_status",
    "top",
    "ulimit",
    "uname",
    "upstart_log",
    "var_lib_dhcp",
    "version",
    "virsh_list_all",
    "xenserver_status_report",
    "xfree86_log",
    "xl_info",
    "xorg_log",
    "xrandr",
    "xset",
    "yellowdog_release",
    "zookeeper_log",
    "comp_fw_log",
    "pegasus_syslog",
    "pegasus_dbglog",
    "dcs_cam_gpus_all",
    "dcs_cam_query_gpu_info",
    "dcs_cam_camera_mapping",
]

def get_dcc_passwd():
    try:
        dcc_passgen = tasks.RunCommand(args=['dcc_passgen'])
        dcc_passgen.run()
        psswd = dcc_passgen.getOutput()
        return psswd.strip()
    except:
        return None

acpi_video_info = tasks.CollectLogFiles(path='/proc/acpi/video/*/info')
application_dump = tasks.CollectLogFiles(path='/var/crash/*.crash')
apt_log = tasks.CollectLogFiles(path='/var/log/apt/*', exclude=r'\d\.gz\Z')
apt_preferences_nvidia = tasks.CollectLogFiles(path='/etc/apt/preferences.d/nvidia')
apt_sources = tasks.CollectLogFiles(path='/etc/apt/sources.list')
apt_sources_list_d = tasks.CollectLogFiles(path='/etc/apt/sources.list.d/*')
bmc_sel_log = tasks.CollectLogFiles(path='/var/log/bmc_sel*.log')
cmdline = tasks.CollectLogFiles(path='/proc/cmdline')
collectd_log = tasks.CollectLogFiles(path='/var/log/collectd.log')
cosmos_log = tasks.CollectLogFiles(path='/var/log/cosmos/*.log', exclude=r'\d\.gz\Z')
cpuinfo = tasks.CollectLogFiles(path='/proc/cpuinfo')
debian_release = tasks.CollectLogFiles(path='/etc/debian_release')
debian_version = tasks.CollectLogFiles(path='/etc/debian_version')
dgx_release = tasks.CollectLogFiles(path='/etc/dgx-release')
dmesg_log = tasks.CollectLogFiles(path='/var/log/dmesg*', exclude=r'\d\.gz\Z')
docker_volume_netshare_log = tasks.CollectLogFiles(path='/var/log/docker-volume-netshare.log')
dshm_log = tasks.CollectLogFiles(path='/var/log/nvsm/dshm/*')
nvsm_log = tasks.CollectLogFiles(path='/var/log/nvsm/*log*')
etc_netplan = tasks.CollectLogFiles(path='/etc/netplan/*.yaml')
fabricmanager_log = tasks.CollectLogFiles(path='/var/log/fabricmanager.log*')
fedora_release = tasks.CollectLogFiles(path='/etc/fedora-release')
fscache_stats = tasks.CollectLogFiles(path='/proc/fs/fscache/stats')
gentoo_release = tasks.CollectLogFiles(path='/etc/gentoo-release')
installer_syslog = tasks.CollectLogFiles(path='/var/log/installer/syslog*', exclude=r'\d\.gz\Z')
interrupts = tasks.CollectLogFiles(path='/proc/interrupts')
iomem = tasks.CollectLogFiles(path='/proc/iomem')
issue = tasks.CollectLogFiles(path='/etc/issue')
kern_log = tasks.CollectLogFiles(path='/var/log/kern.log*')
kernel_log = tasks.CollectLogFiles(path='/var/log/kernel.log*', exclude=r'\d\.gz\Z')
lib_netplan = tasks.CollectLogFiles(path='/lib/netplan/*.yaml')
mandrake_release = tasks.CollectLogFiles(path='/etc/mandrake-release')
mdstat = tasks.CollectLogFiles(path='/proc/mdstat')
meminfo = tasks.CollectLogFiles(path='/proc/meminfo')
mesos_master_error = tasks.CollectLogFiles(path='/var/log/mesos/mesos-master.ERROR')
mesos_master_fatal = tasks.CollectLogFiles(path='/var/log/mesos/mesos-master.FATAL')
mesos_master_info = tasks.CollectLogFiles(path='/var/log/mesos/mesos-master.INFO')
mesos_master_warning = tasks.CollectLogFiles(path='/var/log/mesos/mesos-master.WARNING')
mesos_slave_error = tasks.CollectLogFiles(path='/var/log/mesos/mesos-slave.ERROR')
mesos_slave_fatal = tasks.CollectLogFiles(path='/var/log/mesos/mesos-slave.FATAL')
mesos_slave_info = tasks.CollectLogFiles(path='/var/log/mesos/mesos-slave.INFO')
mesos_slave_warning = tasks.CollectLogFiles(path='/var/log/mesos/mesos-slave.WARNING')
messages = tasks.CollectLogFiles(path='/var/log/messages*', exclude=r'\d\.gz\Z')
modules = tasks.CollectLogFiles(path='/proc/modules')
monit_log = tasks.CollectLogFiles(path='/var/log/monit')
mtrr = tasks.CollectLogFiles(path='/proc/mtrr')
network_interfaces = tasks.CollectLogFiles(path='/etc/network/interfaces')
network_interfaces_d = tasks.CollectLogFiles(path='/etc/network/interfaces.d/*')
nfsfs_servers = tasks.CollectLogFiles(path='/proc/fs/nfsfs/servers')
nfsfs_volumes = tasks.CollectLogFiles(path='/proc/fs/nfsfs/volumes')
nginx_log = tasks.CollectLogFiles(path='/var/log/nginx/*', exclude=r'\d\.gz\Z')
nvidia_application_profiles1 = tasks.CollectLogFiles(path='/etc/nvidia/nvidia-application-profiles-rc')
nvidia_application_profiles2 = tasks.CollectLogFiles(path='/etc/nvidia/nvidia-application-profiles-rc.d/*')
nvidia_application_profiles3 = tasks.CollectLogFiles(path='/usr/share/nvidia/nvidia-application-profiles-*-rc')
nvidia_driver_gpu_information = tasks.CollectLogFiles(path='/proc/driver/nvidia/gpus/*/information')
nvidia_driver_gpu_registry = tasks.CollectLogFiles(path='/proc/driver/nvidia/gpus/*/registry')
nvidia_driver_params = tasks.CollectLogFiles(path='/proc/driver/nvidia/params')
nvidia_driver_registry = tasks.CollectLogFiles(path='/proc/driver/nvidia/registry')
nvidia_driver_version = tasks.CollectLogFiles(path='/proc/driver/nvidia/version')
nvidia_driver_warnings = tasks.CollectLogFiles(path='/proc/driver/nvidia/warnings/*')
nvidia_fs_stats = tasks.CollectLogFiles(path='/proc/driver/nvidia-fs/stats')
nvidia_fs_peer_distance = tasks.CollectLogFiles(path='/proc/driver/nvidia-fs/peer_distance')
nvidia_fs_peer_affinity = tasks.CollectLogFiles(path='/proc/driver/nvidia-fs/peer_affinity')
nvidia_fw_log = tasks.CollectLogFiles(path='/var/log/nvidia-fw.log')
nvidia_installer_log = tasks.CollectLogFiles(path='/var/log/nvidia-installer.log')
nvidia_uninstall_log = tasks.CollectLogFiles(path='/var/log/nvidia-uninstall.log')
nvidia_dcshwapikey_conf = tasks.CollectLogFiles(path='/etc/nvidia/gridd.conf*')
nvidia_dcshwapikey_license = tasks.CollectLogFiles(path='/etc/nvidia/license/NV-*')
pci = tasks.CollectLogFiles(path='/proc/pci')
redhat_release = tasks.CollectLogFiles(path='/etc/redhat-release')
redhat_version = tasks.CollectLogFiles(path='/etc/redhat_version')
release = tasks.CollectLogFiles(path='/etc/release')
remote_bmc_sel_log = tasks.CollectLogFiles(path='/var/log/remote_bmc_sel.log')
run_netplan = tasks.CollectLogFiles(path='/run/netplan/*.yaml')
slackware_release = tasks.CollectLogFiles(path='/etc/slackware-release')
slackware_version = tasks.CollectLogFiles(path='/etc/slackware-version')
sun_release = tasks.CollectLogFiles(path='/etc/sun-release')
syslog = tasks.CollectLogFiles(path='/var/log/syslog*')
system_map = tasks.CollectLogFiles(path='/boot/System.map*')
td_agent_log = tasks.CollectLogFiles(path='/var/log/td-agent/td-agent.*', exclude=r'\d\.gz\Z')
upstart_log = tasks.CollectLogFiles(path='/var/log/upstart/*', exclude=r'\d\.gz\Z')
var_lib_dhcp = tasks.CollectLogFiles(path='/var/lib/dhcp/*')
version = tasks.CollectLogFiles(path='/proc/version')
xfree86_log = tasks.CollectLogFiles(path='/var/log/XFree86.*.log*', exclude=r'\.old\Z')
xorg_log = tasks.CollectLogFiles(path='/var/log/Xorg.*.log*', exclude=r'\.old\Z')
yellowdog_release = tasks.CollectLogFiles(path='/etc/yellowdog-release')
zookeeper_log = tasks.CollectLogFiles(path='/var/log/zookeeper/*.log', exclude=r'\d\.gz\Z')
comp_fw_log = tasks.CollectLogFiles(path='/var/log/comp_fw_log.txt')

import os
from os import path
os.environ['NVSMHEALTH_DUMP_TOOLS'] = os.path.dirname(os.path.abspath(__file__))

#fetching correct cuda path 
os.environ['NVSMHEALTH_DUMP_GDS_CUDA_PATH'] = "/usr/local/cuda"
gds_cuda_tk_vers = config.gds_cuda_versions
for tk in gds_cuda_tk_vers:
    gds_path="/usr/local/cuda-"+ tk +"/gds/tools/gdscheck.py"
    if path.isfile(gds_path):
        os.environ['NVSMHEALTH_DUMP_GDS_CUDA_PATH'] = "/usr/local/cuda-"+ tk
        break


bash = tasks.RunCommand(['bash --version'], shell=True)
bash_hello_world = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/hello.bash'], shell=True)
collect_nvsm = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/collect_nvsm.py'], shell=True)
date = tasks.RunCommand(['date'], shell=True)
date_utc = tasks.RunCommand(['date --utc'], shell=True)
dcgmi_nvlink = tasks.RunCommand(['dcgmi nvlink -s'], shell=True)
dcc_ipmitool_sel_writeraw = tasks.RunCommand(['ipmitool -I lanplus -H {} -U {} -P {} sel writeraw bin_file'.format(platforms.cgx.dcv_bmc_config['ip'], platforms.cgx.dcv_bmc_config['user'], get_dcc_passwd())], shell=True, file_name="dcc_sel_writeraw")
df = tasks.RunCommand(['df -k'], shell=True)
dmesg = tasks.RunCommand(['dmesg'], shell=True)
dmidecode = tasks.RunCommand(['dmidecode'], shell=True)
docker_info = tasks.RunCommand(['docker info'], shell=True)
docker_ps = tasks.RunCommand(['docker ps'], shell=True)
dpkg_list = tasks.RunCommand(['dpkg --list'], shell=True)
dpkg_verify = tasks.RunCommand(['dpkg --verify'], shell=True)
ethtool = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/ethtool.sh'], shell=True)
gcc = tasks.RunCommand(['gcc -v'], shell=True)
gds_check = tasks.RunCommand(['${NVSMHEALTH_DUMP_GDS_CUDA_PATH}/gds/tools/gdscheck.py -pvV'], shell=True)
gds_stats = tasks.RunCommand(['for x in `nvidia-smi --query-compute-apps=pid --format=csv,noheader` ; do ${NVSMHEALTH_DUMP_GDS_CUDA_PATH}/gds/tools/gds_stats -p $x -l 3; done'], shell=True)
gds_stack_trace = tasks.RunCommand(['for x in `nvidia-smi --query-compute-apps=pid --format=csv,noheader` ; do cat /proc/$x/task/*/stack; done'], shell=True)
glxinfo = tasks.RunCommand(['ldd /usr/bin/glxinfo'], shell=True)
gpp = tasks.RunCommand(['g++ -v'], shell=True)
ibstat = tasks.RunCommand(['ibstat'], shell=True)
ibstatus = tasks.RunCommand(['ibstatus'], shell=True)
ibdev2netdev = tasks.RunCommand(['ibdev2netdev'], shell=True)
ibv_devinfo = tasks.RunCommand(['ibv_devinfo'], shell=True)
ip_addr_show = tasks.RunCommand(['ip addr show'], shell=True)
ip_link_show = tasks.RunCommand(['ip link show'], shell=True)
ip_route_show = tasks.RunCommand(['ip route show'], shell=True)
ipmitool_bmc_info = tasks.RunCommand(['ipmitool bmc info'], shell=True)
ipmitool_chassis_status = tasks.RunCommand(['ipmitool chassis status'], shell=True)
ipmitool_fru = tasks.RunCommand(['ipmitool fru'], shell=True)
ipmitool_lan_print = tasks.RunCommand(['ipmitool lan print 1'], shell=True)
ipmitool_power_led_status = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/ipmitool_power_led_status.sh'], shell=True)
ipmitool_raw = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/ipmitool_raw.sh'], shell=True)
ipmitool_raw_dgxa100 = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/ipmitool_raw_dgxa100.sh'], shell=True)
ipmitool_sdr = tasks.RunCommand(['ipmitool sdr'], shell=True)
ipmitool_sdr_dump = tasks.RunCommand(['out=$(mktemp); ipmitool sdr dump $out > /dev/null 2>&1; cat $out'], shell=True, file_name="ipmitool_sdr_dump")
ipmitool_sdr_info = tasks.RunCommand(['ipmitool sdr info'], shell=True)
ipmitool_sel_elist = tasks.RunCommand(['ipmitool sel elist'], shell=True)
ipmitool_sel_info = tasks.RunCommand(['ipmitool sel info'], shell=True)
ipmitool_sel_list = tasks.RunCommand(['ipmitool sel list'], shell=True)
ipmitool_sel_time_get = tasks.RunCommand(['ipmitool sel time get'], shell=True)
ipmitool_sel_writeraw = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/sel_writeraw.sh'], shell=True)
ipmitool_user_list_1 = tasks.RunCommand(['ipmitool user list 1'], shell=True)
java = tasks.RunCommand(['java -version'], shell=True)
java_hello_world = tasks.RunCommand(['java -classpath ${NVSMHEALTH_DUMP_TOOLS}/tools hello'], shell=True)
ldconfig = tasks.RunCommand(['ldconfig -p'], shell=True)
lsb_release = tasks.RunCommand(['lsb_release -a'], shell=True)
lsblk = tasks.RunCommand(['lsblk'], shell=True)
lsblk_discard = tasks.RunCommand(['lsblk --discard'], shell=True)
lsblk_topology = tasks.RunCommand(['lsblk --topology'], shell=True)
lscpu = tasks.RunCommand(['lscpu'], shell=True)
lshw = tasks.RunCommand(['lshw'], shell=True)
lslocks = tasks.RunCommand(['lslocks'], shell=True)
lsmod = tasks.RunCommand(['lsmod'], shell=True)
lspci = tasks.RunCommand(['lspci -vvn'], shell=True)
lspci_plain = tasks.RunCommand(['lspci'], shell=True)
lspci_tree = tasks.RunCommand(['lspci -t'], shell=True)
lsusb = tasks.RunCommand(['lsusb'], shell=True)
lsusb_tree = tasks.RunCommand(['lsusb -t'], shell=True)
lsusb_verbose = tasks.RunCommand(['lsusb --verbose'], shell=True)
mdadm_detail = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/mdadm-detail.sh'], shell=True)
mdadm_examine = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/mdadm-examine.sh'], shell=True)
mlxcables = tasks.RunCommand(['mst start && mst cable add && mlxcables'], shell=True)
modinfo = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/modinfo.sh'], shell=True)
mount = tasks.RunCommand(['mount'], shell=True)
ntpq = tasks.RunCommand(['ntpq -p'], shell=True)
numactl = tasks.RunCommand(['numactl --hardware'], shell=True)
nvcc = tasks.RunCommand(['nvcc --version'], shell=True)
nvidia_address_text = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/nvidia_address_text.py'], shell=True)
nvidia_debugdump = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/nvidia-debugdump.sh'], shell=True)
nvidia_dkms_log = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/nvidia-dkms-log.sh'], shell=True)
nvidia_driver_ko = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/nvidia_driver_ko.py'], shell=True)
nvidia_settings = tasks.RunCommand(['nvidia-settings -q all'], shell=True)
nvidia_smi = tasks.RunCommand(['nvidia-smi'], shell=True)
nvidia_smi_nvlink = tasks.RunCommand(['nvidia-smi topo -p2p rw >/dev/null && nvidia-smi nvlink -s'], shell=True)
nvidia_smi_query = tasks.RunCommand(['nvidia-smi -q'], shell=True)
nvidia_smi_query_unit = tasks.RunCommand(['nvidia-smi -q -u'], shell=True)
nvidia_smi_topo = tasks.RunCommand(['nvidia-smi topo -m'], shell=True)
nvidia_smi_xml = tasks.RunCommand(['nvidia-smi -q -x'], shell=True)
nvidia_vm_health_check_show = tasks.RunCommand(['nvidia-vm health-check show'], shell=True)
nvidia_vm_image_show = tasks.RunCommand(['nvidia-vm image show'], shell=True)
nvidia_vm_resources_show = tasks.RunCommand(['nvidia-vm resources show'], shell=True)
nvme_list = tasks.RunCommand(['nvme list'], shell=True)
nvme_logs = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/nvme-logs.sh'], shell=True)
nvsm_health_show_debug = tasks.RunCommand(['nvsm-health --show --log-level=debug'], shell=True)
nvsm_show = tasks.RunCommand(['nvsm show -level all'], shell=True)
nvsm_show_alerts = tasks.RunCommand(['nvsm show alerts'], shell=True)
nvsm_show_debug = tasks.RunCommand(['nvsm --log-level=debug show -level all'], shell=True)
ofed_info = tasks.RunCommand(['ofed_info'], shell=True)
perl = tasks.RunCommand(['perl -v'], shell=True)
perl_hello_world = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/hello.pl'], shell=True)
ping_compute = tasks.RunCommand(['ping -w 5 ngc.nvidia.com'], shell=True)
printenv = tasks.RunCommand(['printenv'], shell=True)
ps = tasks.RunCommand(['ps -wwo pid,uid,pcpu,pmem,etime,state,ppid,user,args --pid 2 --ppid 2 --deselect'], shell=True)
ps_aux = tasks.RunCommand(['ps aux'], shell=True)
psu_info_dgx1 = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/psu_info_dgx1.sh'], shell=True)
python = tasks.RunCommand(['python --version'], shell=True)
python_hello_world = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/hello.py'], shell=True)
service_cachefilesd_status = tasks.RunCommand(['service cachefilesd status'], shell=True)
service_status_all = tasks.RunCommand(['service --status-all'], shell=True)
smartctl = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/smartctl.sh'], shell=True)
smartctl_scan = tasks.RunCommand(['smartctl --scan'], shell=True)
storcli_cmds = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/storcli_cmds.sh'], shell=True)
sysctl = tasks.RunCommand(['sysctl -a'], shell=True)
timedatectl_status = tasks.RunCommand(['timedatectl status'], shell=True)
top = tasks.RunCommand(['top -b -n 5'], shell=True)
ulimit = tasks.RunCommand(['bash -c "ulimit -a"'], shell=True)
uname = tasks.RunCommand(['uname -a'], shell=True)
virsh_list_all = tasks.RunCommand(['virsh list --all'], shell=True)
xenserver_status_report = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/xenserver-status-report.sh'], shell=True, binary_output=True)
xl_info = tasks.RunCommand(['xl info'], shell=True)
xrandr = tasks.RunCommand(['xrandr --verbose'], shell=True)
xset = tasks.RunCommand(['xset -q'], shell=True)

dcs_cam_gpus_all = tasks.RunCommand(['python3 ${NVSMHEALTH_DUMP_TOOLS}/dcs_camera_info.py --cmd gpus_all --display 0'], shell=True)
dcs_cam_query_gpu_info = tasks.RunCommand(['python3 ${NVSMHEALTH_DUMP_TOOLS}/dcs_camera_info.py --cmd query_gpu_info'], shell=True)
dcs_cam_camera_mapping = tasks.RunCommand(['python3 ${NVSMHEALTH_DUMP_TOOLS}/dcs_camera_info.py --cmd camera_mapping --display 0'], shell=True)

hca_self_test = tasks.RunCommand(['hca_self_test.ofed'], shell=True)
mlx_fetch_arm_log = tasks.RunCommand(['${NVSMHEALTH_DUMP_TOOLS}/mlnx_arm_logs.sh'], shell=True)
