#!/usr/bin/env sh

# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

# Look for all RAID disks appearing in sysfs
for volume in $(find /sys/block -mindepth 1 -maxdepth 1 -name 'md*' | sort); do
  for disk in $(find "${volume}/md" -mindepth 1 -maxdepth 1 -name 'dev-*' | sort); do
    # We now know where this RAID disk resides in /sys, but in order to call
    # "mdadm --examine" we must now determine where it resides under /dev.
    #
    # The task of placing devices under /dev is normally handled by udev, but
    # we can find this information ourselves by parsing the "uevent" file
    # using Bash. This is the same information that udev used to create the
    # device file under the /dev directory.
    uevent="${disk}/block/uevent"
    if [ ! -f "$uevent" ]; then
      continue
    fi
    # DEVNAME appears in the "uevent" file as "DEVNAME=sdx"
    unset DEVNAME
    . "${uevent}"  # Parse with Bash
    if [ "$?" != "0" ]; then
      continue
    fi
    if [ -z "$DEVNAME" ]; then
      continue
    fi
    block_device="/dev/${DEVNAME}"
    if [ ! -b "$block_device" ]; then
      continue
    fi
    # Examine the superblock of this disk using mdadm
    echo "=======> mdadm --examine "$block_device" <========="
    mdadm --examine "$block_device"
  done
done
