#!/usr/bin/env python3

# Copyright (c) 2020, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

import subprocess
import re

driver_path = "modinfo nvidia | grep filename"
driver_version = "dkms status nvidia*"
nvidia_ko_path = "/var/lib/dkms/nvidia/{}/{}/x86_64/module/nvidia.ko"
symbol_table_cmd = "/usr/bin/nm {} | grep ' t '"

def get_nvidia_driver_path():
    out = subprocess.check_output(driver_path, shell=True)
    filename = out.decode("utf-8")
    pattern = re.compile(r'^.*/modules/(?P<name>.*)/updates/.*', re.IGNORECASE)
    names = re.search(pattern, filename)
    if names:
        return names.group("name").strip()

def get_nvidia_driver_version(driver_path):
    out = subprocess.check_output(driver_version, shell=True)
    res = out.decode("utf-8")
    versions = res.split('\n')
    version = ""
    for v in versions:
        v = v.lower()
        if "nvidia," in v and driver_path in v:
            version = v
            break

    if version:
        ver = version.split(",")
        return ver[1].strip()

    return version

def get_nvidia_ko_path(driver_version, driver_path):
    return nvidia_ko_path.format(driver_version, driver_path)

def print_symbol_table_output(nvidia_ko_path):
    cmd = symbol_table_cmd.format(nvidia_ko_path)
    out = subprocess.check_output(cmd, shell=True)
    res = out.decode("utf-8")
    print(res)

def main():
    driver_path = get_nvidia_driver_path()
    driver_version = get_nvidia_driver_version(driver_path)
    path = get_nvidia_ko_path(driver_version, driver_path)
    print_symbol_table_output(path)

if __name__ == "__main__":
    main()

