import re
import json
from nvsmhealth import modules, tasks

__all__ = [
#    'run_lshw',
#    'parse_lshw',
]

run_lshw = tasks.RunCommand(
    args=['lshw','-json', '-sanitize', '-disable', 'usb']) \
    .title('''Run the lshw command''') \
    .describe('''
            Verify the hardware bill of materials using the
            lshw[https://www.ezix.org/project/wiki/HardwareLiSter] cmd.
            This command require superuser privileges.''') \
    .depends(modules.common.check_superuser_privileges)

class ParseLshw(tasks.ITask):
    def __init__(self, run_lshw_task):
        super().__init__()
        self.depends(run_lshw_task)
        self.__run_lshw_task = run_lshw_task
        self.__result = None

    def getResult(self):
        return self.__result

    def run(self):
        output = self.__run_lshw_task.getOutput().strip()
        j = json.loads(output)

        # Replace 'children' lists with dictionary entries
        for level1 in j.get('children', []):
            for level2 in level1.get('children', []):
                for level3 in level2.get('children', []):
                    for level4 in level3.get('children', []):
                        for level5 in level4.get('children', []):
                            for level6 in level5.get('children', []):
                                level5[level6.get('id')] = level6
                            level5.pop('children', None)
                            level4[level5.get('id')] = level5
                        level4.pop('children', None)
                        level3[level4.get('id')] = level4
                    level3.pop('children', None)
                    level2[level3.get('id')] = level3
                level2.pop('children', None)
                level1[level2.get('id')] = level2
            level1.pop('children', None)
            j[level1.get('id')] = level1
        j.pop('children', None)

        self.__result = j

parse_lshw = ParseLshw(run_lshw) \
        .title('Parse lshw output')
