# Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express

import json
import re
from nvsmhealth import modules, tasks, config

__all__ = [
    'parameters'
]

class Parameters(tasks.ITask):
    def __init__(self, platform_task):
        super(Parameters, self).__init__()
        self.depends(platform_task)
        self.__parameters = {}
        self.__platform_task = platform_task

    def getResult(self):
        return self.__parameters

    def run(self):
        platform = self.__platform_task.getPlatform()
        parameters = platform.getParameters()
        # Parameters stored in this task are global for all ICheck tasks
        for param, value in parameters.items():
            self.__parameters[param] = value

parameters = Parameters(modules.platform.determine_platform) \
    .title('''Initialise platform parameters after determining the platform''')

