# Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from nvsmhealth import tasks

__all__ = [
  'sysfs_dmi_system_vendor',
  'sysfs_dmi_product_name',
  'sysfs_dmi_bios_version',
  'fru_dcc_version'
]

sysfs_dmi_system_vendor = tasks.RunCommand(
        args=['cat', '/sys/devices/virtual/dmi/id/sys_vendor']) \
    .title('''Determine system vendor in DMI table via sysfs''') \
    .describe('''
            This command reads the system vendor name (sometimes also
            "Manufacturer") stored in the DMI table by reading its value
            using sysfs. On DGX systems this will be "NVIDIA", but might be
            some other string depending on the system. This command does
            not require superuser privileges.''')

sysfs_dmi_product_name = tasks.RunCommand(
        args=['cat', '/sys/devices/virtual/dmi/id/product_name']) \
    .title('''Determine product name in DMI table via sysfs''') \
    .describe('''
            This command reads the product name stored in the DMI table by
            reading its value using sysfs. The product name is used to
            determine which platform NVSysinfo is running on, e.g. DGX-1,
            DGX-2, or DGX Station. This command does not require superuser
            privileges.''')

sysfs_dmi_bios_version = tasks.RunCommand(
        args=['cat', '/sys/devices/virtual/dmi/id/bios_version']) \
    .title('''Determine BIOS version in DMI table via sysfs''') \
    .describe('''
            This command reads the BIOS version stored in the DMI table by
            reading its value using sysfs. The product name is used to
            determine which BIOS version is running with, e.g. DGX-1,
            DGX-2, or DGX Station. This command does not require superuser
            privileges.''')

fru_dcc_version = tasks.RunCommand(
        shell=True,
        args=["ipmitool fru print 0 | grep -E 'Product Extra(\s+):' | head -n 3 | awk 'NR==3 {{print $4}}'"]) \
    .title('''Determine system version using DCC version stored in DCS FRU''') \
    .describe('''
            This command reads the dcc version 
            stored in the DCS FRU table by reading its value
            using ipmitool. On C1.1 systems this will be "1.1". 
            This command does not require superuser privileges.''')


