# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from nvsmhealth import modules, tasks, config

__all__ = [
    'run_gpu_monitor_status',
    'check_gpu_monitor_active'
]

run_gpu_monitor_status = tasks.RunCommand(
        #args=['systemctl', 'status', 'nvsm-plugin-gpumonitor']) \
        args=['nvsm_core', '--mode=client', 'GET', '/nvsm/v1/Systems/1/GPUs']) \
        .title('''Execute GET on nvsm_core''') \
        .describe('''
                This runs the "nvsm_core --mode=client GET /nvsm/v1/Systems/1/GPUs" command to obtain gpumonitor
                status information.''') \
        .depends(modules.common.check_superuser_privileges)


class CheckGpuMonitorActive(tasks.ITask):
    def __init__(self, run_gpu_monitor_status):
        super(CheckGpuMonitorActive, self).__init__()

        # Declare dependency on nvidia_smi using the ITask interface
        self.__run_task = run_gpu_monitor_status
        self.depends(run_gpu_monitor_status)
        self.__result = False

    def getResult(self):
        return self.__result

    def run(self):

        if self.__run_task.getReturnCode() or not self.__run_task.getOutput():
            return

        out = self.__run_task.getOutput().split('\n')
        for line in out:
            if 'Code' in line:
                if '200' in line:
                    self.__result = True

check_gpu_monitor_active = CheckGpuMonitorActive(run_gpu_monitor_status) \
    .title('''Check if nvsm_core GPU URI is populated''') \
    .depends(run_gpu_monitor_status)
