# Copyright (c) 2019, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

__all__ = [
    "blacklist_recommendations",
    "blacklist_recommendations_instant",
    "dcs_camera",
    "dcs_can_cfg",
    "dcs_dcv_bmc",
    "dcs_dcv_firmware",
    "dcs_dcv_sensor_threshold",
    "dcs_grid_license",
    "dcs_nv_settings_cfg",
    "dcs_usb_serial_cfg",
    "dcs_usb_tree",
    "dcv_fan_bom",
    "dcv_psu_bom",
    "dimm_bom",
    "disk_controllers_bom",
    "dmidecode_dimm_vendors",
    "drive_gpu_sm_count",
    "enable_dcv_checks",
    "ethernet_controller_info",
    "ethernet_controllers_bom",
    "fan_bom",
    "fru_devices",
    "gpu_bom",
    "gpu_direct_topology",
    "gpu_link_info",
    "gpu_nvlink_speed",
    "gpu_nvlink_active_count",
    "gpu_sm_count",
    "gpu_total_retired_page_count",
    "ib_controller_link_info",
    "ib_controllers_bom",
    "lscpu_number_of_cores",
    "mdadm_disk_status",
    "mdadm_volume_status",
    "meminfo_memory_size",
    "mlnx_firmware_check",
    "net_link",
    "net_ping",
    "nvme",
    "nvme_check_smart_log",
    "nvme_link_info",
    "nvswitch_bom",
    "pcie_switches_bom",
    "psu_bom",
    "skip_bmc_revision_check",
    "smartctl_check_ssd_brick",
    "smartctl_megaraid_disk_count",
    "storcli_disk_stats",
    "storcli_phy_links",
    "storcli_platform_string",
    "summary_base_os_string",
    "summary_serial_num_string",
    "sw_rel_file",
    "vga_bom",
    "xenserver_number_of_cores",
]

class IParameter(object):
    ''' Class representing a platform parameter within the NVSM Health

        IParameter does not do much right now other than storing documentation
        strings. In the future, this class could be extended to represent
        strongly-typed parameters or to provide parameter validation.
    '''
    def __init__(self):
        self.__name = None
        self.__title = None
        self.__description = None

    def name(self, text):
        self.__name = text
        return self

    def getName(self):
        return self.__name

    def title(self, text):
        self.__title = text
        return self

    def getTitle(self):
        return self.__title

    def describe(self, text):
        self.__description = text
        return self

    def getDescription(self):
        return self.__description

blacklist_recommendations = IParameter() \
    .title('''Flag to enable "blacklist recommendation" check for NVIDIA GPUs''') \
    .describe('''This is a boolean flag to enable a "blacklist recommendation"
        check, which tests NVIDIA GPUs on the system and might recommend
        removing certain GPUs for subsequent triage. In a production
        environment with many GPUs installed, there can be one or more GPUs on
        the system that are not in an operational state. To avoid undue impact
        to production jobs, these GPUs can be temporarily blacklisted (or
          disabled) while processing continues on operational GPUs. Reasons for
        blacklisting GPUs might include pending page retirements or PCIe
        connectivity problems.''')
blacklist_recommendations_instant = IParameter() \
    .title('''Flag to enable a quick version of the "blacklist recommendation" check for NVIDIA GPUs''') \
    .describe('''This flag enables a quick-running subset of the "blacklist
    recommendation" check. This quick check is suitable for running
    periodically or for running as a job preamble.''')
dcs_camera = IParameter() \
    .title('''Flag to enable checks related to the NVIDIA DRIVE Constellation Simulator virtual cameras''')
dcs_can_cfg = IParameter() \
    .title('''Parameters for logging into the CAN Interface for NVIDIA DRIVE Constellation Simulator''')
dcs_dcv_bmc = IParameter() \
    .title('''Flag to enable checks related to the BMC of NVIDIA DRIVE Constellation Vehicle''')
dcs_dcv_firmware = IParameter() \
    .title('''Flag to enable checks related to the NVIDIA DRIVE Constellation Vehicle firmware''')
dcs_dcv_sensor_threshold = IParameter() \
    .title('''Flag to enable sensor threshold checks for NVIDIA DRIVE Constellation Vehicle''')
dcs_grid_license = IParameter() \
    .title('''Flag to enable license check for NVIDIA DRIVE Constellation Simulator GRID''')
dcs_nv_settings_cfg = IParameter() \
    .title('''Parameters used to check NVIDIA settings used by NVIDIA DRIVE Constellation Simulator''')
dcs_usb_serial_cfg = IParameter() \
    .title('''Parameters used to check the USB serial connection between DCS and DCV''')
dcs_usb_tree = IParameter() \
    .title('''List of USB devices required by NVIDIA DRIVE Constellation Simulator''')
dcv_fan_bom = IParameter() \
    .title('''List of fan sensors expected by NVIDIA DRIVE Constellation Simulator''')
dcv_psu_bom = IParameter() \
    .title('''List of PSU sensors expected by NVIDIA DRIVE Constellation Simulator''')
dimm_bom = IParameter() \
    .title('''List of expected DIMMs (including DIMM slots)''')
disk_controllers_bom = IParameter() \
    .title('''List of disk controllers expected on PCIe bus''')
dmidecode_dimm_vendors = IParameter() \
    .title('''List of recognized DIMM vendors''')
drive_gpu_sm_count = IParameter() \
    .title('''Expected streaming multiprocessor count per GPU on NVIDIA DRIVE Constellation Simulator''')
enable_dcv_checks = IParameter() \
    .title('''Enable checks for NVIDIA DRIVE Constellation Vehicle''')
ethernet_controller_info = IParameter() \
    .title('''Expected Ethernet controller properties on PCIe bus''')
ethernet_controllers_bom = IParameter() \
    .title('''List of expected Ethernet controllers on PCIe bus''')
fan_bom = IParameter() \
    .title('''List of expected fan sensors on BMC''')
fru_devices = IParameter() \
    .title('''List of BMC FRU devices to check for serial number consistency''')
gpu_bom = IParameter() \
    .title('''List of expected GPUs on PCIe bus''')
gpu_direct_topology = IParameter() \
    .title('''Expected topology for NVIDIA GPUDirect''')
gpu_link_info = IParameter() \
    .title('''Expected link width and speed for GPUs on PCIe bus''')
gpu_nvlink_speed = IParameter() \
    .title('''Expected NVLink speed for NVIDIA GPUs connected with NVLink''')
gpu_nvlink_active_count = IParameter() \
    .title('''Expected NVLink active for NVIDIA GPUs connected with NVLink''')
gpu_sm_count = IParameter() \
    .title('''Expected streaming multiprocessor count per GPU''')
gpu_total_retired_page_count = IParameter() \
    .title('''Maximum number of retired pages per GPU (currently 60)''')
ib_controller_link_info = IParameter() \
    .title('''Expected link width and speed for InfiniBand controllers on PCIe bus''')
ib_controllers_bom = IParameter() \
    .title('''Expected InfiniBand controllers on PCIe bus''')
lscpu_number_of_cores = IParameter() \
    .title('''Expected number of total logical CPU cores on the system''')
mdadm_disk_status = IParameter() \
    .title('''Enable disk status check for Linux software RAID''')
mdadm_volume_status = IParameter() \
    .title('''Enable volume status check for Linux software RAID''')
meminfo_memory_size = IParameter() \
    .title('''Expected system memory size in kilobytes''')
mlnx_firmware_check = IParameter() \
    .title('''Flag to enable check of Mellanox firmware version consistency''')
net_link = IParameter() \
    .title('''List of link-layer connectivity checks''') \
    .describe('''Currently, this is only used to check network connectivity of
                 devices attached to NVIDIA DRIVE Constellation Simulator''')
net_ping = IParameter() \
    .title('''List of network-layer connectivity checks''') \
    .describe('''Currently, this is only used to check network connectivity of
                 devices attached to NVIDIA DRIVE Constellation Simulator''')
nvme = IParameter() \
    .title('''List of expected NVMe drives (including capacity)''')
nvme_check_smart_log = IParameter() \
    .title('''Flag to enable SMART check for NVMe drives''')
nvme_link_info = IParameter() \
    .title('''Expected link width and speed of NVMe drives on PCIe bus''')
nvswitch_bom = IParameter() \
    .title('''List of expected NVSwitch devices on PCIe bus''')
pcie_switches_bom = IParameter() \
    .title('''List of expected switches on PCIe bus''')
psu_bom = IParameter() \
    .title('''List of expected PSU sensors on BMC''')
skip_bmc_revision_check = IParameter() \
    .title('''Flag to disable check for BMC Revision''')
smartctl_check_ssd_brick = IParameter() \
    .title('''Flag to enable check for SSD drives reporting erroneous SMART information''')
smartctl_megaraid_disk_count = IParameter() \
    .title('''Expected MegaRAID disk count (including capacity) reported by smartctl''')
storcli_disk_stats = IParameter() \
    .title('''Expected MegaRAID physical disk status reported by StorCLI''')
storcli_phy_links = IParameter() \
    .title('''Expected MegaRAID physical link status reported by StorCLI''')
storcli_platform_string = IParameter() \
    .title('''String used to display platform (e.g. DGX) in StorCLI check messages''')
summary_base_os_string = IParameter() \
    .title('''String used in display messages to refer to platform OS''')
summary_serial_num_string = IParameter() \
    .title('''String used in display messages to refer to platform serial number''')
sw_rel_file = IParameter() \
    .title('''Name of file used to store OS release version information''')
vga_bom = IParameter() \
    .title('''List of expected VGA controllers on PCI bus (usually for BMC)''')
xenserver_number_of_cores = IParameter() \
    .title('''Expected number of virtual CPU cores (when running in XenServer hypervisor)''')
