#!/usr/bin/python3
import os, sys, argparse, subprocess

script_name = 'dcs_camera_info'
script_description = 'Display CGX GPU/Camera information and mappings'

def getArgs():
    parser = argparse.ArgumentParser(prog = script_name, description = script_description)

    parser.add_argument('--cmd', choices=[ 'gpus_all', 'query_gpu_info', 'camera_mapping' ])
    parser.add_argument('--display')

    return parser.parse_args()

def print_results(header, output, error):
    header_div = "================================================================================"
    if output:
        print (header_div)
        print (header)
        print (header_div)
        print ()
        print (output)
    if error:
        print (header_div, file=sys.stderr)
        print (header, file=sys.stderr)
        print (header_div, file=sys.stderr)
        print ("", file=sys.stderr)
        print (error, file=sys.stderr)

def execute_gpus_all(disp_num):
    cmd_gpus = 'DISPLAY=:{} nvidia-settings -q gpus -V all'.format(disp_num)
    results_gpus = subprocess.run([cmd_gpus], stdout=subprocess.PIPE, universal_newlines=True, shell=True)
    print_results(cmd_gpus, results_gpus.stdout, None)

def execute_query_gpu_info():
    cmd_gpu_info = 'nvidia-xconfig --query-gpu-info'
    results_gpu_info = subprocess.run([cmd_gpu_info], stdout=subprocess.PIPE, universal_newlines=True, shell=True)
    print_results(cmd_gpu_info, results_gpu_info.stdout, None)

def execute_camera_mapping(disp_num):
    cmd_screens = 'DISPLAY=:{} nvidia-settings -q screens | grep -P \[\[\]'.format(disp_num)
    results_screens = subprocess.run([cmd_screens], stdout=subprocess.PIPE, universal_newlines=True, shell=True)
    scrn_list = []
    for l in results_screens.stdout.split('\n'):
        nl = l.strip(' ').strip('[')
        cp = nl.find(']')
        scrn = nl[0:cp]
        if scrn:
            scrn_list.append('{}.{}'.format(disp_num, scrn))

    cameras = {"FTC:30:231" : "d-1", "FWC:120:231" : "d-0", "FCL:120:231" : "c-0", "FCR:120:231" : "c-1", "RAR:120:231" : "b-1", "RAL:120:231" : "b-0", "FNC:60:231" : "a-0", "RNC:60:231" : "a-1"}
    camera_map = []
    for s in scrn_list:
        cmd_edid_info = "DISPLAY=:{} xrandr ".format(s)
        cmd_edid_info = cmd_edid_info+"--verbose | awk \'/[:.]/ && hex { sub(/.*000000fc00/, \"\", hex); hex = substr(hex, 0, 26); print hex; hex=\"\" } hex { gsub(/[ \\t]+/, \"\"); hex = hex $0 } /EDID.*:/ { hex=\" \" }\' | xxd -r -p"
        results_edid_info = subprocess.run([cmd_edid_info], stdout=subprocess.PIPE, universal_newlines=True, shell=True)
        cam = results_edid_info.stdout
        nl = cam.find('\n')
        if nl > 0:
            cam = cam[0:(nl)]

        cam_name = cameras.get(cam, None)
        if cam_name:
            camera_map.append("X-Screen {} | {} | {}".format(s, cam, cam_name))
        else:
            camera_map.append("X-Screen {} | {}".format(s, cam))

    print_results("Camera Mapping", "\n".join(camera_map), None)

def execute_command(args):
    if not args.cmd:
        print ("ERROR: No command specified!")
        return

    if not args.display and (args.cmd == 'gpus_all' or args.cmd == 'camera_mapping'):
        print ("ERROR: No display number specified specified!")
        return

    if args.cmd == 'gpus_all':
        execute_gpus_all(args.display)
    elif args.cmd == 'query_gpu_info':
        execute_query_gpu_info()
    elif args.cmd == 'camera_mapping':
        execute_camera_mapping(args.display)

def main():
    args = getArgs()
    execute_command(args)

if __name__ == "__main__":
    main()

