#!/usr/bin/env bash
# Copyright (c) 2018, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

ipmitool_raw() {
  COMMAND="ipmitool raw $@" 
  echo "========> ${COMMAND} <========"
  ${COMMAND}
}

ipmitool_raw_hex() {
  COMMAND="ipmitool raw $@" 
  echo "========> ${COMMAND} <========"
  ${COMMAND} | xxd -r 
}

if grep -qi 'A100' /sys/devices/virtual/dmi/id/product_name ; then

  echo "FW Versions: MB FPGA, GB FPGA, MID FPGA. Offset 1. Output ASCII."
  for hex in 0x00 0x01 0x08 ; do
    ipmitool_raw 0x3c 0x0f ${hex}
  done
  echo "FW Versions: PSU. Offset 1. Output ASCII."
  for i in $(seq 2 7) ; do
    ipmitool_raw 0x3c 0x0f "0x0${i}"
  done

  echo "FW Versions: CEC Version"
  ipmitool_raw 0x3c 0x03 0x09
  echo " "

  echo "FW Versions: Active BMC"
  ipmitool_raw 0x3c 0x03 0x20
  echo " "

  echo "FW Versions: Inactive BMC"
  ipmitool_raw 0x3c 0x03 0x21
  echo " "

  echo "PSU Information"
  for i in $(seq 0 5) ; do
    echo "PSU${i}"
    echo -n "MFR ID: "
    ipmitool_raw_hex 0x3c 0x0e "0x0${i}" 0x02
    echo ""
    echo -n "Model: "
    ipmitool_raw_hex 0x3c 0x0e "0x0${i}" 0x01
    echo " "
    echo "Serial: "
    ipmitool_raw_hex 0x3c 0x0e "0x0${i}" 0x00
    echo " "
    echo " "
    echo "PSU Data"
    ipmitool_raw 0x3c 0x78 0x00 "0x0${i}"
    echo " "
    echo " "
    sleep 1
  done

  echo "Nvidia OEM Command Version"
  ipmitool_raw 0x3c 0x01
  echo " "

  echo "Get Firmware Bootup slot"
  ipmitool_raw 0x3c 0x03 0x00
  echo " "

  echo "Get BIOS Bootup Slot"
  ipmitool_raw 0x3c 0x1e
  echo " "

  echo "Get BIOS Next Boot Slot"
  ipmitool_raw 0x3c 0x22
  echo " "

  echo "Get BIOS Version (Primary Slot)"
  ipmitool_raw 0x3c 0x24 0x00
  echo " "

  echo "Get BIOS Version (Secondary Slot)"
  ipmitool_raw 0x3c 0x24 0x01
  echo " "

  echo "Get BIOS Config"
  ipmitool_raw 0x3c 0x21 0x01
  echo " "

  echo "Get BMC Diagnostic SEL State"
  ipmitool_raw 0x3c 0x66
  echo " "

  echo "Get Max-P/Max-Q Mode"
  ipmitool_raw 0x3c 0x80 0x00
  echo " "

  echo "Current Chassis Power Limit (W)"
  ipmitool_raw 0x3c 0x80 0x01
  echo " "

  echo "Chassis Power Limit P"
  ipmitool_raw 0x3c 0x80 0x02
  echo " "

  echo "Chassis Power Limit Q"
  ipmitool_raw 0x3c 0x80 0x03
  echo " "

  echo "Chassis Power Limit Min"
  ipmitool_raw 0x3c 0x80 0x04
  echo " "

  echo "Get Chassis Power Limit Max"
  ipmitool_raw 0x3c 0x80 0x05
  echo " "

  echo "Get Rest of System Power"
  ipmitool_raw 0x3c 0x80 0x06
  echo " "

  echo "Get Sensor Monitor Control"
  ipmitool_raw 0x3c 0x86
  echo " "

  echo "Get LED Status (Power LED)"
  ipmitool_raw 0x3c 0x65 0x00
  echo " "

  echo "Get LED Status (Fault LED)"
  ipmitool_raw 0x3c 0x65 0x01
  echo " "

  echo "Get LED Status (Motherboard debug LED)"
  ipmitool_raw 0x3c 0x65 0x10
  echo " "

  echo "Get LED Status(CEC alive LED)"
  ipmitool_raw 0x3c 0x65 0x20
  echo " "

  echo "Get LED Status(CEC State LED)"
  ipmitool_raw 0x3c 0x65 0x21
  echo " "

  echo "Get MB CPLD Registers"
  ipmitool_raw 0x30 0x81 0x01 0x78 0x0C 0
  echo " "

  echo "Get MID CPLD Registers"
  ipmitool_raw 0x30 0x81 0x02 0x78 0x31 0
  echo " "

  echo "Get SSD LED (0-7) Status"
  for i in $(seq 0 7) ; do
    echo "SSD ${i}"
    echo -n "Ready to remove LED: "
    ipmitool_raw_hex 0x3c 0x64 0x30 "0x0${i}"
    echo ""
    echo -n "Activity LED: "
    ipmitool_raw_hex 0x3c 0x64 0x31 "0x0${i}"
    echo " "
    echo "Fault LED: "
    ipmitool_raw_hex 0x3c 0x64 0x32 "0x0${i}"
    echo " "
    echo " "
  done

  echo "Get CEC Boot Status (CEC)"
  ipmitool_raw 0x3c 0x68 0x00
  echo " "

  echo "Get CEC Boot Status (FPGA-CEC)"
  ipmitool_raw 0x3c 0x68 0x01
  echo " "

  echo "Get BMC EEPROM Dump"
  ipmitool_raw 0x30 0x81 0x01 0xa8 0x20 0x00 0x80
  echo " "

  echo "Dump FPGA Registers"
  ipmitool_raw 0x30 0x81 0x0b 0xc0 0x05 0x5c 0x04 0xb4 0x99 0x56 0x80
  ipmitool_raw 0x30 0x81 0x0b 0x12 0x50 0x00
  ipmitool_raw 0x30 0x81 0x0b 0xc0 0x05 0x5c 0x04 0xb4 0x99 0xff 0x80
  echo " "


fi



