(function () {
  /**
   * Returns boolean of whether an element is a list item
   * @param {Element} element
   */
  var isParentMenuItem = function (element) { return element.nodeName === 'UL' || element.nodeName === 'LI' }

  /**
   * Checks the parent element of the provided element
   * and adds 'current' class.
   * Will repeat for all parent list elements until all list items
   * in this tree contain the 'current' class.
   * @param {Element} element
   */
  var loopThroughParents = function (element) {
    var parent = element.parentElement
    if (isParentMenuItem(parent)) {
      parent.classList.add('current')  
      loopThroughParents(parent)
    }
  }

  /**
   * Clears all instances of '.current' within the sidebar
   */
  var clearActiveMenus = function () {
    document.querySelectorAll('.menu .current').forEach(function (element) {
      element.classList.remove('current')
    })
  }

  /**
   * On page load, will clear all 'current' classes, which in
   * turn will close all menus. Also, removes 'current' classes
   * that Sphinx adds (since the way Sphinx does it makes collapsible
   * menus difficult to deal with).
   * 
   * After menus are cleared, it will then add the correct 'current'
   * class to the menu tree relative to the current page.
   */
  var getInitialOpenMenus = function () {
    clearActiveMenus()
    var openedLink = document.querySelector('.sidebar [href="' + location.hash + '"]') || document.querySelector('.sidebar [href="#"]')
    openedLink && loopThroughParents(openedLink)
  }

  /**
   * A click handler that will clear all menu state, then
   * loop through all parent list elements and add 'current'
   * class to them.
   * @param {Element} element
   */
  var addClick = function (element) {
    element.addEventListener('click', function (event) {
      clearActiveMenus()
      loopThroughParents(element)
    })
  }

  // Clear current menu selection
  getInitialOpenMenus()

  /**
   * Move the Sphinx generated list caption to be
   * housed within the list element.
   *
   * Example:
   * From:
   * <p class='caption'>Menu Title</p>
   * <ul>
   *   <li>menu item</li>
   * </ul>
   * 
   * To:
   * <ul>
   *   <p class='caption'>Menu Title</p>
   *   <li>menu item</li>
   * </ul>
   */
  var blocks = document.querySelectorAll('.menu .caption')
  blocks.forEach(function (element) {
    var list = element.nextElementSibling
    list.prepend(element)
  })

  // Add expanding click handlers to clickable list headline elements
  document.querySelectorAll('.menu .caption, .menu .toctree-l1 a, .menu .toctree-l2 a').forEach(addClick)
})()
